(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7304,        229]*)
(*NotebookOutlinePosition[      8534,        268]*)
(*  CellTagsIndexPosition[      8490,        264]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Basics for HW#1"
}], "Title",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Below are a few simple commands that will come in useful in some of your \
homeworks.  Notice a few basics:\n\t-All commancs start with a capital letter \
and use the square brackets [ ].\n\t-Variables start with lower case.\n\t\
-Anytime you want a brief description of a command just use the ?CommandName \
function. (see below)  Two ??s gives even more info.\n\t-Becareful about your \
variables.  They stay set forever unless you explicitly change them or use \
the Clear[variable] command.\n\t\t\nWork through the following in a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session and see what you get.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " should be available in any student computer lab. Turn in printouts of \
your work.\n\nFirst, quick and easy plotting.  Here's an example,  but feel \
free to play with different functions.\t"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?Plot\)\)], "Input"],

Cell[BoxData[
    \(Plot[Sin[x], {x, 0, 2*Pi}]\)], "Input"],

Cell[TextData[StyleBox[
"Notice that Pi is a \"command\".  If you don't believe me...numerically \
evaluate it to...hmm... let's say....67 digits.",
  FontFamily->"Times New Roman"]], "Text",
  FontFamily->"Courier"],

Cell[BoxData[
    \(N[Pi, 67]\)], "Input"],

Cell["While we're at it...how about e, too!", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(N[E, 67]\)], "Input"],

Cell[TextData[{
  "We'll be solving lots of differential equations in this class.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can solve them too using DSolve, so this gives you a way to ",
  StyleBox["check",
    FontWeight->"Bold"],
  " your math on your homework! "
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?DSolve\)\)], "Input"],

Cell[TextData[{
  "The expression below solves the simple equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(d\^2\) y\)\/dx\^2\)]],
  "=2, with boundary conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`\([dy\/dx]\)\_0\)]],
  "=0 and y[0]=0"
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(DSolve[{\(\(y'\)'\)[x] == 2, \(y'\)[0] == 0, y[0] == 4}, y[x], x]\)], 
  "Input"],

Cell[TextData[{
  "Some differential equations will not be easily solvable, so we'll want to \
use numerical techniques.  NDSolve is ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s numerical solver."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?NDSolve\)\)], "Input"],

Cell[BoxData[
    \(solution\  = \ 
      NDSolve[{\(\(y'\)'\)[x] == 2, \(y'\)[0] == 0, y[0] == 4}, 
        y[x], {x, 0, 2}]\)], "Input"],

Cell[TextData[{
  "Notice that you don't have an answer; it's imbedded in a list of numbers \
not shown.  The best way to look at the solution is a plot.  We use the \
variable ",
  StyleBox["solution",
    FontSlant->"Italic"],
  " so that Plot knows what list of numbers to plot.  Also, that weird \"/.\" \
sign below tells the Evaluate command to look in",
  StyleBox[" solution",
    FontSlant->"Italic"],
  " for the list of y[x] values.  The PlotRange command gives the y-axis \
range.  Try the plot with and without the PlotRange command."
}], "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(Plot[Evaluate[y[x]\  /. \ solution], {x, 0, 2}, \ PlotRange -> {0, 8}]
      \)], "Input"],

Cell["\<\
Does the plot look like it should?
These DiffyQ solvers can also solve coupled differential equations.  You can \
try it if you want; you'll be a leg up on next week's homework......

Below is an example of solving coupled Differential Equations.\
\>", "Text",
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(ClearAll[]; \n
    solution2\  = \ 
      NDSolve[{\(\(y'\)'\)[x] == 2 + \(z'\)[x], 
          \(\(z'\)'\)[x] == 3 + 5*\(y'\)[x], 
          \(y'\)[0] == \(z'\)[0] == z[0] == 0, y[0] == 4}, {y, z}, {x, 0, 2}]
        \)], "Input"],

Cell["\<\
Now to see y and z functions, we can either plot them versus each other (a \
Parametric plot)..
\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot[Evaluate[{y[x], z[x]}\  /. \ solution2], {x, 0, 2}]\)], 
  "Input"],

Cell["....Or...we can overlay to plots of y vs. x and z vs. x....", "Text"],

Cell[BoxData[
    \(Show[Plot[Evaluate[y[x]\  /. \ solution2], {x, 0, 2}], \n\t
      Plot[Evaluate[z[x]\  /. \ solution2], {x, 0, 2}]]\)], "Input"]
}, Open  ]],

Cell[TextData[{
  "When you are ready to print the whole thing out, please do the following \
to minimize paper usage\n\[Bullet]Go back through the document and clean \
things up, like deleting unnecessary returns, trial runs, and pesky messages \
about variables being named like other variables, etc...\n\[Bullet]Then click \
on ",
  StyleBox["Format",
    FontWeight->"Bold"],
  " on the Toolbar and choose ",
  StyleBox["Printing Style Environment -> Printout",
    FontWeight->"Bold"],
  ".\n\[Bullet]Under ",
  StyleBox["File",
    FontWeight->"Bold"],
  " click ",
  StyleBox["Printing Settings -> Page Setup",
    FontWeight->"Bold"],
  " and make sure you're set for Portrait.\n\[Bullet]Now under ",
  StyleBox["File",
    FontWeight->"Bold"],
  " click ",
  StyleBox["Print",
    FontWeight->"Bold"],
  ".  In the print dialog box choose the ",
  StyleBox["Layout",
    FontWeight->"Bold"],
  " tab and select 2 pages per sheet.\n\[Bullet]Click ",
  StyleBox["Print",
    FontWeight->"Bold"],
  "."
}], "Text"]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
CellGrouping->Manual,
WindowSize->{595, 521},
WindowMargins->{{0, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 5, 103, "Title"],
Cell[1868, 58, 938, 17, 242, "Text"],
Cell[2809, 77, 42, 1, 30, "Input"],
Cell[2854, 80, 59, 1, 30, "Input"],
Cell[2916, 83, 216, 4, 33, "Text"],
Cell[3135, 89, 42, 1, 30, "Input"],
Cell[3180, 92, 86, 1, 33, "Text"],
Cell[3269, 95, 41, 1, 30, "Input"],
Cell[3313, 98, 328, 9, 52, "Text"],
Cell[3644, 109, 44, 1, 30, "Input"],
Cell[3691, 112, 298, 9, 42, "Text"],
Cell[3992, 123, 101, 2, 30, "Input"],
Cell[4096, 127, 257, 7, 52, "Text"],
Cell[4356, 136, 45, 1, 30, "Input"],
Cell[4404, 139, 138, 3, 30, "Input"],
Cell[4545, 144, 591, 13, 90, "Text"],
Cell[5139, 159, 110, 2, 30, "Input"],
Cell[5252, 163, 303, 7, 109, "Text"],
Cell[5558, 172, 250, 6, 90, "Input"],
Cell[5811, 180, 120, 4, 52, "Text"],
Cell[5934, 186, 102, 2, 30, "Input"],
Cell[6039, 190, 75, 0, 33, "Text"],
Cell[6117, 192, 148, 2, 50, "Input"]
}, Open  ]],
Cell[6280, 197, 1020, 30, 144, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

