(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    101235,       2840]*)
(*NotebookOutlinePosition[    101960,       2865]*)
(*  CellTagsIndexPosition[    101916,       2861]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Phy 319 -- HW#2", "Title"],

Cell["\<\
We want to first numerically solve the differential equations we found in \
class for  the generalized incldine plane with friction.  We had two coupled \
differential equations in the x- and z-directions.  

Below is a set of input lines, the first few of which input some given \
constants.\
\>", "Text"],

Cell[BoxData[
    \(ClearAll[]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(g = 9.8\), "\n", 
    \(muk = 0.3\), "\n", 
    \(\(\(theta = 30.  Degree\)\(\n\)
    \)\)}], "Input"],

Cell[BoxData[
    \(9.8`\)], "Output"],

Cell[BoxData[
    \(0.3`\)], "Output"],

Cell[BoxData[
    \(0.5235987755982988`\)], "Output"]
}, Open  ]],

Cell["\<\
Here we solve the diff. Eq. for x(t) and z(t), remembering to put in the  \
initial conditions (all of which are zero except the initial z-velocity).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nsolution\  = \ 
      NDSolve[{\(\(x'\)'\)[t] == 
            g*Sin[theta]\  - \ 
              muk*g*Cos[theta]*\(x'\)[t]/
                  Sqrt[\(x'\)[t]^2 + \(z'\)[t]^2], \ \(\(z'\)'\)[
              t] == \(-muk\)*g*
              Cos[theta]*\(z'\)[t]/Sqrt[\(x'\)[t]^2 + \(z'\)[t]^2], \ 
          x[0] == z[0] == \(x'\)[0] == 0, \(z'\)[0] == 0.2}, {x, z}, {t, 0, 
          2}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"x", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 2.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"z", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 2.`}}, "<>"]\),
              False,
              Editable->False]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["Now let's plot with axes the x-motion vs. the z-motion.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[x[t] /. nsolution], {t, 0, 0.25}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 3.80952 0.0147151 6.62271 [
[.21429 .00222 -12 -9 ]
[.21429 .00222 12 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -12 -9 ]
[.59524 .00222 12 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .14717 -24 -4.5 ]
[.01131 .14717 0 4.5 ]
[.01131 .27962 -24 -4.5 ]
[.01131 .27962 0 4.5 ]
[.01131 .41208 -24 -4.5 ]
[.01131 .41208 0 4.5 ]
[.01131 .54453 -24 -4.5 ]
[.01131 .54453 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.05)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.1)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.15)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.2)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(0.25)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14717 m
.03006 .14717 L
s
[(0.02)] .01131 .14717 1 0 Mshowa
.02381 .27962 m
.03006 .27962 L
s
[(0.04)] .01131 .27962 1 0 Mshowa
.02381 .41208 m
.03006 .41208 L
s
[(0.06)] .01131 .41208 1 0 Mshowa
.02381 .54453 m
.03006 .54453 L
s
[(0.08)] .01131 .54453 1 0 Mshowa
.125 Mabswid
.02381 .04783 m
.02756 .04783 L
s
.02381 .08094 m
.02756 .08094 L
s
.02381 .11406 m
.02756 .11406 L
s
.02381 .18028 m
.02756 .18028 L
s
.02381 .2134 m
.02756 .2134 L
s
.02381 .24651 m
.02756 .24651 L
s
.02381 .31274 m
.02756 .31274 L
s
.02381 .34585 m
.02756 .34585 L
s
.02381 .37896 m
.02756 .37896 L
s
.02381 .44519 m
.02756 .44519 L
s
.02381 .47831 m
.02756 .47831 L
s
.02381 .51142 m
.02756 .51142 L
s
.02381 .57765 m
.02756 .57765 L
s
.02381 .61076 m
.02756 .61076 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01473 L
.02846 .01474 L
.03053 .01477 L
.03279 .0148 L
.03527 .01486 L
.0379 .01493 L
.04262 .0151 L
.05205 .01558 L
.06244 .01631 L
.07293 .01726 L
.0842 .01851 L
.10458 .02134 L
.1458 .02908 L
.18551 .03883 L
.22371 .05013 L
.26435 .0641 L
.30348 .07935 L
.34506 .09746 L
.38513 .11673 L
.42368 .13694 L
.46468 .16022 L
.50417 .18436 L
.54214 .20918 L
.58257 .23731 L
.62148 .26605 L
.66284 .2984 L
.70268 .33131 L
.74101 .36458 L
.78179 .40171 L
.82106 .43916 L
.85881 .47672 L
.89901 .51841 L
.9377 .56018 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00@P3oool2000000@0oooo0P00
00040?ooo`800000103oool200000240oooo0P0000040?ooo`8000000`3oool5000001h0oooo0P00
00040?ooo`8000000`3oool500000080oooo0P00000Q0?ooo`800000103oool2000000<0oooo1000
000P0?ooo`800000103oool2000000<0oooo100000030?ooo`8000000`3oool00440oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001l0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0M0?ooo`040000003oool0oooo
000000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01d0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`00@@3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool07@3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool01@3oool100000040oooo0@3oool00440oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000030?ooo`800000803oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo01d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`800000
803oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool00440oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01l0oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`0M0?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00P3oool00480oooo0P00000:0?ooo`800000103oool3
00000200oooo0P00000:0?ooo`800000803oool2000000X0oooo0P0000040?ooo`<00000803oool2
000000X0oooo0P00000Q0?ooo`8000002P3oool2000000@0oooo0`0000020?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo000E0?ooool000001P0000060?ooo`006`3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo0?ooo`X000001@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo01D0oooo1@00003X0?ooo`006`3o
ool00`000000oooo0?ooo`0J0?ooo`@00000i03oool001/0oooo00<000000?ooo`3oool07P3oool4
00000>00oooo000K0?ooo`030000003oool0oooo0280oooo1000003L0?ooo`006`3oool00`000000
oooo0?ooo`0V0?ooo`<00000f@3oool001/0oooo00<000000?ooo`3oool0:@3oool300000=H0oooo
000K0?ooo`800000;@3oool400000=80oooo000K0?ooo`030000003oool0oooo0300oooo0`00003?
0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`800000c@3oool001/0oooo00<000000?ooo`3o
ool0=@3oool300000<X0oooo000K0?ooo`030000003oool0oooo03P0oooo0P0000380?ooo`006`3o
ool00`000000oooo0?ooo`0j0?ooo`<00000a@3oool001/0oooo00<000000?ooo`3oool0?@3oool4
00000<40oooo000K0?ooo`030000003oool0oooo0440oooo1000002m0?ooo`006`3oool00`000000
oooo0?ooo`150?ooo`800000^`3oool001/0oooo0P0000180?ooo`800000^@3oool001/0oooo00<0
00000?ooo`3oool0B@3oool200000;L0oooo000K0?ooo`030000003oool0oooo04/0oooo0P00002e
0?ooo`006`3oool00`000000oooo0?ooo`1=0?ooo`800000/`3oool001/0oooo00<000000?ooo`3o
ool0C`3oool300000;00oooo000K0?ooo`030000003oool0oooo0580oooo0P00002^0?ooo`006`3o
ool00`000000oooo0?ooo`1D0?ooo`800000[03oool001/0oooo00<000000?ooo`3oool0EP3oool2
00000:X0oooo000K0?ooo`030000003oool0oooo05P0oooo0P00002X0?ooo`006`3oool2000005/0
oooo0P00002V0?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`800000Y03oool001/0oooo00<0
00000?ooo`3oool0GP3oool200000:80oooo000K0?ooo`030000003oool0oooo0600oooo0P00002P
0?ooo`006`3oool00`000000oooo0?ooo`1R0?ooo`800000WP3oool001/0oooo00<000000?ooo`3o
ool0I03oool2000009`0oooo00020?ooo`800000103oool2000000@0oooo0P0000030?ooo`@00000
103oool00`000000oooo0?ooo`1V0?ooo`800000VP3oool000050?ooo`000000oooo0?ooo`000000
203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`2G0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool2000006X0oooo00<000000?oo
o`3oool0UP3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0JP3oool2000009H0oooo00001@3o
ool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0T`3oool00080oooo0P00
000:0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0K@3oool2000009<0oooo000K
0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0T03oool001/0oooo00<000000?oo
o`3oool0L03oool200000900oooo000K0?ooo`030000003oool0oooo0780oooo0P00002>0?ooo`00
6`3oool00`000000oooo0?ooo`1d0?ooo`800000S03oool001/0oooo00<000000?ooo`3oool0MP3o
ool2000008X0oooo000K0?ooo`800000N@3oool2000008P0oooo000K0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0Q@3oool001/0oooo00<000000?ooo`3oool0N`3oool2000008D0
oooo000K0?ooo`030000003oool0oooo07d0oooo0P0000230?ooo`006`3oool00`000000oooo0?oo
o`1o0?ooo`030000003oool0oooo0800oooo000K0?ooo`030000003oool0oooo0800oooo0P000020
0?ooo`006`3oool00`000000oooo0?ooo`220?ooo`800000OP3oool001/0oooo00<000000?ooo`3o
ool0Q03oool00`000000oooo0?ooo`1k0?ooo`006`3oool2000008H0oooo00<000000?ooo`3oool0
NP3oool001/0oooo00<000000?ooo`3oool0QP3oool2000007X0oooo000K0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0M`3oool001/0oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`1f0?ooo`006`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo07D0
oooo000K0?ooo`030000003oool0oooo08/0oooo0P00001e0?ooo`006`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo0780oooo000K0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0L@3oool001/0oooo00<000000?ooo`3oool0S`3oool200000740oooo000K0?ooo`80
0000TP3oool00`000000oooo0?ooo`1^0?ooo`006`3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo06d0oooo000K0?ooo`030000003oool0oooo09<0oooo0P00001]0?ooo`006`3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo06X0oooo000K0?ooo`030000003oool0oooo
09H0oooo0P00001Z0?ooo`006`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo06L0
oooo000K0?ooo`030000003oool0oooo09T0oooo0P00001W0?ooo`000P3oool2000000@0oooo0P00
00040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`1T0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo06<0oooo
00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool5000000<0
oooo0P00002N0?ooo`800000H`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0W`3oool0
0`000000oooo0?ooo`1P0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`2P0?ooo`030000003o
ool0oooo05l0oooo00020?ooo`8000002P3oool2000000D0oooo0P0000040?ooo`030000003oool0
oooo0:40oooo0P00001O0?ooo`006`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo
05`0oooo000K0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0F`3oool001/0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`1J0?ooo`006`3oool00`000000oooo0?oo
o`2V0?ooo`030000003oool0oooo05T0oooo000K0?ooo`800000Z03oool00`000000oooo0?ooo`1H
0?ooo`006`3oool00`000000oooo0?ooo`2X0?ooo`800000F03oool001/0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`1E0?ooo`006`3oool00`000000oooo0?ooo`2[0?ooo`030000
003oool0oooo05@0oooo000K0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0D`3o
ool001/0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`1B0?ooo`006`3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo0540oooo000K0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool0D03oool001/0oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`1?0?ooo`006`3oool200000;80oooo00<000000?ooo`3oool0CP3oool001/0oooo00<00000
0?ooo`3oool0/P3oool2000004h0oooo000K0?ooo`030000003oool0oooo0;@0oooo00<000000?oo
o`3oool0B`3oool001/0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`1:0?ooo`00
6`3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo04T0oooo000K0?ooo`030000003o
ool0oooo0;L0oooo00<000000?ooo`3oool0B03oool001/0oooo00<000000?ooo`3oool0^03oool0
0`000000oooo0?ooo`170?ooo`006`3oool00`000000oooo0?ooo`2i0?ooo`800000A`3oool001/0
oooo0P00002l0?ooo`030000003oool0oooo04@0oooo000K0?ooo`030000003oool0oooo0;`0oooo
00<000000?ooo`3oool0@`3oool001/0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`120?ooo`006`3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo0440oooo000K0?oo
o`030000003oool0oooo0;l0oooo0P0000110?ooo`006`3oool00`000000oooo0?ooo`310?ooo`03
0000003oool0oooo03h0oooo000K0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0
?@3oool00080oooo0P0000040?ooo`800000103oool2000000<0oooo0`0000050?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?03oool000050?ooo`000000oooo0?ooo`000000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0a03oool00`000000oooo0?ooo`0k0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool200000<H0oooo00<00000
0?ooo`3oool0>P3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`00
00020?ooo`<000001@3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03T0oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0>03oool00080oooo0P00
000:0?ooo`800000103oool3000000@0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?oo
o`0g0?ooo`006`3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo03H0oooo000K0?oo
o`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0=@3oool001/0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0d0?ooo`006`3oool00`000000oooo0?ooo`3<0?ooo`030000
003oool0oooo03<0oooo000K0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0<P3o
ool001/0oooo0P00003?0?ooo`030000003oool0oooo0340oooo000K0?ooo`030000003oool0oooo
0<l0oooo00<000000?ooo`3oool0<03oool001/0oooo00<000000?ooo`3oool0d03oool00`000000
oooo0?ooo`0_0?ooo`006`3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo02h0oooo
000K0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0;@3oool001/0oooo00<00000
0?ooo`3oool0d`3oool00`000000oooo0?ooo`0/0?ooo`006`3oool00`000000oooo0?ooo`3D0?oo
o`030000003oool0oooo02/0oooo000K0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3o
ool0:P3oool001/0oooo0P00003G0?ooo`030000003oool0oooo02T0oooo000K0?ooo`030000003o
ool0oooo0=L0oooo00<000000?ooo`3oool0:03oool001/0oooo00<000000?ooo`3oool0f03oool0
0`000000oooo0?ooo`0W0?ooo`006`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo
02H0oooo000K0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool09@3oool001/0oooo
00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0T0?ooo`006`3oool00`000000oooo0?oo
o`3K0?ooo`030000003oool0oooo02@0oooo000K0?ooo`030000003oool0oooo0=`0oooo00<00000
0?ooo`3oool08`3oool001/0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0R0?oo
o`006`3oool200000=l0oooo00<000000?ooo`3oool08@3oool001/0oooo00<000000?ooo`3oool0
g`3oool00`000000oooo0?ooo`0P0?ooo`006`3oool00`000000oooo0?ooo`3P0?ooo`030000003o
ool0oooo01l0oooo000K0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool07P3oool0
01/0oooo00<000000?ooo`3oool0hP3oool00`000000oooo0?ooo`0M0?ooo`006`3oool00`000000
oooo0?ooo`3S0?ooo`030000003oool0oooo01`0oooo000K0?ooo`030000003oool0oooo0>@0oooo
00<000000?ooo`3oool06`3oool00080oooo0P0000040?ooo`800000103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3oool06P3oool000050?ooo`000000
oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`0J0?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool2
00000>L0oooo00<000000?ooo`3oool06@3oool000050?ooo`000000oooo0?ooo`000000203oool0
10000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000oooo0?ooo`3W0?ooo`030000003o
ool0oooo01P0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3o
ool05`3oool00080oooo0P00000:0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
j@3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`3Z0?ooo`030000003o
ool0oooo01D0oooo000K0?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool0503oool0
01/0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`0C0?ooo`006`3oool00`000000
oooo0?ooo`3]0?ooo`030000003oool0oooo0180oooo000K0?ooo`800000k`3oool00`000000oooo
0?ooo`0A0?ooo`006`3oool00`000000oooo0?ooo`3_0?ooo`030000003oool0oooo0100oooo000K
0?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool03`3oool001/0oooo00<000000?oo
o`3oool0l@3oool00`000000oooo0?ooo`0>0?ooo`006`3oool00`000000oooo0?ooo`3b0?ooo`03
0000003oool0oooo00d0oooo000K0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0
303oool001/0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`0;0?ooo`006`3oool0
0`000000oooo0?ooo`3e0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo
0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0275008, -0.00935854, \
0.0010091, 0.000580454}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(p1 = 
      ParametricPlot[Evaluate[{z[t], x[t]} /. nsolution], {t, 0, 0.25}, \ 
        AxesLabel -> \ {"\<z,accros\>", "\<x,down\>"}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 56.6006 0.0147151 6.62271 [
[.16531 .00222 -18 -9 ]
[.16531 .00222 18 0 ]
[.30681 .00222 -15 -9 ]
[.30681 .00222 15 0 ]
[.44831 .00222 -18 -9 ]
[.44831 .00222 18 0 ]
[.58982 .00222 -12 -9 ]
[.58982 .00222 12 0 ]
[.73132 .00222 -18 -9 ]
[.73132 .00222 18 0 ]
[.87282 .00222 -15 -9 ]
[.87282 .00222 15 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 52 6.28125 ]
[.01131 .14717 -24 -4.5 ]
[.01131 .14717 0 4.5 ]
[.01131 .27962 -24 -4.5 ]
[.01131 .27962 0 4.5 ]
[.01131 .41208 -24 -4.5 ]
[.01131 .41208 0 4.5 ]
[.01131 .54453 -24 -4.5 ]
[.01131 .54453 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16531 .01472 m
.16531 .02097 L
s
[(0.0025)] .16531 .00222 0 1 Mshowa
.30681 .01472 m
.30681 .02097 L
s
[(0.005)] .30681 .00222 0 1 Mshowa
.44831 .01472 m
.44831 .02097 L
s
[(0.0075)] .44831 .00222 0 1 Mshowa
.58982 .01472 m
.58982 .02097 L
s
[(0.01)] .58982 .00222 0 1 Mshowa
.73132 .01472 m
.73132 .02097 L
s
[(0.0125)] .73132 .00222 0 1 Mshowa
.87282 .01472 m
.87282 .02097 L
s
[(0.015)] .87282 .00222 0 1 Mshowa
.125 Mabswid
.05211 .01472 m
.05211 .01847 L
s
.08041 .01472 m
.08041 .01847 L
s
.10871 .01472 m
.10871 .01847 L
s
.13701 .01472 m
.13701 .01847 L
s
.19361 .01472 m
.19361 .01847 L
s
.22191 .01472 m
.22191 .01847 L
s
.25021 .01472 m
.25021 .01847 L
s
.27851 .01472 m
.27851 .01847 L
s
.33511 .01472 m
.33511 .01847 L
s
.36341 .01472 m
.36341 .01847 L
s
.39171 .01472 m
.39171 .01847 L
s
.42001 .01472 m
.42001 .01847 L
s
.47661 .01472 m
.47661 .01847 L
s
.50491 .01472 m
.50491 .01847 L
s
.53322 .01472 m
.53322 .01847 L
s
.56152 .01472 m
.56152 .01847 L
s
.61812 .01472 m
.61812 .01847 L
s
.64642 .01472 m
.64642 .01847 L
s
.67472 .01472 m
.67472 .01847 L
s
.70302 .01472 m
.70302 .01847 L
s
.75962 .01472 m
.75962 .01847 L
s
.78792 .01472 m
.78792 .01847 L
s
.81622 .01472 m
.81622 .01847 L
s
.84452 .01472 m
.84452 .01847 L
s
.90112 .01472 m
.90112 .01847 L
s
.92942 .01472 m
.92942 .01847 L
s
.95772 .01472 m
.95772 .01847 L
s
.98602 .01472 m
.98602 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(accros) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .14717 m
.03006 .14717 L
s
[(0.02)] .01131 .14717 1 0 Mshowa
.02381 .27962 m
.03006 .27962 L
s
[(0.04)] .01131 .27962 1 0 Mshowa
.02381 .41208 m
.03006 .41208 L
s
[(0.06)] .01131 .41208 1 0 Mshowa
.02381 .54453 m
.03006 .54453 L
s
[(0.08)] .01131 .54453 1 0 Mshowa
.125 Mabswid
.02381 .04783 m
.02756 .04783 L
s
.02381 .08094 m
.02756 .08094 L
s
.02381 .11406 m
.02756 .11406 L
s
.02381 .18028 m
.02756 .18028 L
s
.02381 .2134 m
.02756 .2134 L
s
.02381 .24651 m
.02756 .24651 L
s
.02381 .31274 m
.02756 .31274 L
s
.02381 .34585 m
.02756 .34585 L
s
.02381 .37896 m
.02756 .37896 L
s
.02381 .44519 m
.02756 .44519 L
s
.02381 .47831 m
.02756 .47831 L
s
.02381 .51142 m
.02756 .51142 L
s
.02381 .57765 m
.02756 .57765 L
s
.02381 .61076 m
.02756 .61076 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(down) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.0273 .01472 L
.03046 .01472 L
.03409 .01473 L
.03751 .01474 L
.04356 .01477 L
.05008 .0148 L
.0572 .01486 L
.06469 .01493 L
.07794 .0151 L
.09139 .01533 L
.10379 .01558 L
.13124 .01631 L
.15819 .01727 L
.18191 .01834 L
.23222 .02134 L
.27265 .02458 L
.31357 .02875 L
.38523 .03867 L
.44522 .05025 L
.50122 .06457 L
.54908 .08027 L
.59054 .09709 L
.63053 .1168 L
.66569 .13752 L
.69687 .15906 L
.72761 .18372 L
.75513 .20912 L
.78245 .23792 L
.8071 .26741 L
.82944 .2974 L
.8519 .33105 L
.87236 .36514 L
.89108 .39948 L
.91006 .43773 L
.92749 .47619 L
.94519 .51885 L
.9615 .56166 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00:03oool2000000@0oooo0P0000040?ooo`800000103oool2000000<0
oooo100000030?ooo`@00000103oool2000000@0oooo0P0000040?ooo`800000103oool4000000@0
oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool00P3oool2000000@0
oooo0P0000040?ooo`800000103oool2000000<0oooo1@0000000`3oool00000000000040?ooo`80
0000103oool2000000<0oooo1@0000000`3oool0000000000002000000<0oooo0P0000000`3oool0
0000000000040?ooo`800000103oool2000000<0oooo1@0000020?ooo`800000B03oool002L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00`3oool01P000000oooo000000000000oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool00000
0000003oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?oo
o`0000001@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
A@3oool002L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000oooo
00L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`80000000<0
oooo0000003oool01`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A@3oool002L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool01P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo0P0000020?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0
oooo0?ooo`8000000`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool0
0`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3o
ool2000004P0oooo000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P0000020?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`170?ooo`00:03oool2000000X0oooo0P0000040?ooo`800000103o
ool2000000@0oooo1000000:0?ooo`800000103oool2000000@0oooo1000000:0?ooo`800000103o
ool2000000<0oooo100000030?ooo`<000000`3oool2000000X0oooo0P0000040?ooo`8000000`3o
ool2000000X0oooo0P0000040?ooo`800000103oool2000000@0oooo1@00000:0?ooo`800000103o
ool2000000@0oooo0`0000170?ooo`00o`3ooolQ0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
o`@0oooo000J0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0:03oool001X0oooo
00<000000?ooo`3oool0d@3oool4000000<0oooo00<000000?ooo`3oool00P3oool500000080oooo
0`0000030?ooo`<000000P3oool4000000<0oooo0P0000030?ooo`<000001@3oool001D0ooood@00
00090?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool0oooo100000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool001X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool>000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000<0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo0`0000050?ooo`006P3oool00`000000oooo0?ooo`0S0?oooa80
0000W03oool4000000T0oooo0`0000030?ooo`<000000`3oool300000080oooo100000030?ooo`80
00000`3oool4000000@0oooo000J0?ooo`030000003oool0oooo03D0oooo200000360?ooo`006P3o
ool00`000000oooo0?ooo`0m0?ooo`P00000_P3oool001X0oooo00<000000?ooo`3oool0A@3oool6
00000;P0oooo000J0?ooo`030000003oool0oooo04/0oooo1000002d0?ooo`006P3oool200000500
oooo1000002`0?ooo`006P3oool00`000000oooo0?ooo`1C0?ooo`@00000[03oool001X0oooo00<0
00000?ooo`3oool0E`3oool400000:P0oooo000J0?ooo`030000003oool0oooo05/0oooo1000002T
0?ooo`006P3oool00`000000oooo0?ooo`1O0?ooo`<00000X@3oool001X0oooo00<000000?ooo`3o
ool0HP3oool3000009h0oooo000J0?ooo`030000003oool0oooo06D0oooo1000002J0?ooo`006P3o
ool2000006X0oooo0`00002G0?ooo`006P3oool00`000000oooo0?ooo`1/0?ooo`<00000U03oool0
01X0oooo00<000000?ooo`3oool0K`3oool300000940oooo000J0?ooo`030000003oool0oooo0780
oooo0P00002?0?ooo`006P3oool00`000000oooo0?ooo`1d0?ooo`800000S@3oool001X0oooo00<0
00000?ooo`3oool0MP3oool2000008/0oooo000J0?ooo`030000003oool0oooo07P0oooo0P000029
0?ooo`006P3oool2000007/0oooo0P0000270?ooo`006P3oool00`000000oooo0?ooo`1l0?ooo`80
0000Q@3oool001X0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`220?ooo`006P3o
ool00`000000oooo0?ooo`1o0?ooo`800000PP3oool001X0oooo00<000000?ooo`3oool0P@3oool2
00000800oooo00020?ooo`800000103oool2000000@0oooo0P0000030?ooo`@000000`3oool00`00
0000oooo0?ooo`230?ooo`030000003oool0oooo07d0oooo00001@3oool000000?ooo`3oool00000
00P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08@0oooo0P00001m0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00`3oool2000008L0oooo00<000000?ooo`3oool0NP3o
ool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0Q`3oool2000007X0oooo00001@3oool000000?oo
o`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo08T0oooo00<000000?ooo`3oool0M`3oool00080oooo0P00000:0?ooo`80
0000103oool2000000@0oooo00<000000?ooo`3oool0RP3oool2000007L0oooo000J0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0M03oool001X0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`1c0?ooo`006P3oool00`000000oooo0?ooo`2>0?ooo`800000L`3oool0
01X0oooo0P00002A0?ooo`030000003oool0oooo0700oooo000J0?ooo`030000003oool0oooo0940
oooo00<000000?ooo`3oool0K`3oool001X0oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`1^0?ooo`006P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo06h0oooo000J
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0K@3oool001X0oooo00<000000?oo
o`3oool0U03oool00`000000oooo0?ooo`1/0?ooo`006P3oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo06/0oooo000J0?ooo`800000U`3oool00`000000oooo0?ooo`1Z0?ooo`006P3o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo06T0oooo000J0?ooo`030000003oool0
oooo09P0oooo00<000000?ooo`3oool0J03oool001X0oooo00<000000?ooo`3oool0V@3oool00`00
0000oooo0?ooo`1W0?ooo`006P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo06H0
oooo000J0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0I@3oool001X0oooo0P00
002M0?ooo`030000003oool0oooo06@0oooo000J0?ooo`030000003oool0oooo09d0oooo00<00000
0?ooo`3oool0H`3oool001X0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`1S0?oo
o`006P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo0680oooo000J0?ooo`030000
003oool0oooo09l0oooo00<000000?ooo`3oool0H@3oool00080oooo0P0000040?ooo`800000103o
ool2000000D0oooo0`0000020?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0H03o
ool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`050000
003oool0oooo0?ooo`000000X`3oool00`000000oooo0?ooo`1O0?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`040000003oool0oooo00000080oooo1@0000020?ooo`800000X`3oool00`00
0000oooo0?ooo`1N0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`2R0?ooo`030000003o
ool0oooo05h0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000030?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0
G@3oool00080oooo0P00000:0?ooo`8000001@3oool2000000<0oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`1L0?ooo`006P3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo05/0oooo000J0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0FP3oool001X0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`1J0?ooo`006P3oool200000:P0oooo
00<000000?ooo`3oool0F@3oool001X0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?oo
o`1I0?ooo`006P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo05P0oooo000J0?oo
o`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0F03oool001X0oooo00<000000?ooo`3o
ool0Z@3oool00`000000oooo0?ooo`1G0?ooo`006P3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo05H0oooo000J0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0EP3o
ool001X0oooo0P00002/0?ooo`030000003oool0oooo05D0oooo000J0?ooo`030000003oool0oooo
0:`0oooo00<000000?ooo`3oool0E03oool001X0oooo00<000000?ooo`3oool0[@3oool00`000000
oooo0?ooo`1C0?ooo`006P3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo05<0oooo
000J0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0DP3oool001X0oooo00<00000
0?ooo`3oool0[`3oool00`000000oooo0?ooo`1A0?ooo`006P3oool00`000000oooo0?ooo`2_0?oo
o`030000003oool0oooo0540oooo000J0?ooo`800000/@3oool00`000000oooo0?ooo`1@0?ooo`00
6P3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo0500oooo000J0?ooo`030000003o
ool0oooo0;40oooo00<000000?ooo`3oool0C`3oool001X0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`1?0?ooo`006P3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo
04h0oooo00020?ooo`800000103oool2000000@0oooo0P0000030?ooo`<00000103oool00`000000
oooo0?ooo`2b0?ooo`030000003oool0oooo04h0oooo00001@3oool000000?ooo`3oool0000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0;<0oooo00<000000?ooo`3oool0C@3oool000050?ooo`000000oooo0?ooo`000000203oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00002d0?ooo`030000
003oool0oooo04d0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool0
00000P3oool3000000@0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`1<0?ooo`00
00D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo04`0oooo00020?ooo`80
00002P3oool2000000@0oooo0`0000030?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool0B`3oool001X0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`1;0?ooo`006P3o
ool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo04X0oooo000J0?ooo`030000003oool0
oooo0;H0oooo00<000000?ooo`3oool0BP3oool001X0oooo0P00002h0?ooo`030000003oool0oooo
04T0oooo000J0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0B@3oool001X0oooo
00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`190?ooo`006P3oool00`000000oooo0?oo
o`2h0?ooo`030000003oool0oooo04P0oooo000J0?ooo`030000003oool0oooo0;P0oooo00<00000
0?ooo`3oool0B03oool001X0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`170?oo
o`006P3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo04L0oooo000J0?ooo`800000
^P3oool00`000000oooo0?ooo`170?ooo`006P3oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo04H0oooo000J0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0AP3oool0
01X0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`150?ooo`006P3oool00`000000
oooo0?ooo`2k0?ooo`030000003oool0oooo04D0oooo000J0?ooo`030000003oool0oooo0;`0oooo
00<000000?ooo`3oool0A03oool001X0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?oo
o`140?ooo`006P3oool200000;h0oooo00<000000?ooo`3oool0@`3oool001X0oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`130?ooo`006P3oool00`000000oooo0?ooo`2m0?ooo`03
0000003oool0oooo04<0oooo000J0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
@P3oool00080oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool0@P3oool000050?ooo`000000oooo0?ooo`000000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0_P3oool00`000000oooo0?ooo`120?ooo`0000D0oooo0000003oool0oooo000000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool200000<00oooo00<00000
0?ooo`3oool0@@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`00
00030?ooo`800000103oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo0440oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@@3oool00080oooo
0P00000:0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0`03oool00`000000oooo
0?ooo`100?ooo`006P3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo0400oooo000J
0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@03oool001X0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0o0?ooo`006P3oool200000<80oooo00<000000?ooo`3o
ool0?`3oool001X0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0o0?ooo`006P3o
ool00`000000oooo0?ooo`320?ooo`030000003oool0oooo03h0oooo000J0?ooo`030000003oool0
oooo0<80oooo00<000000?ooo`3oool0?P3oool001X0oooo00<000000?ooo`3oool0`P3oool00`00
0000oooo0?ooo`0n0?ooo`006P3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo03d0
oooo000J0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0?@3oool001X0oooo0P00
003o0?ooo`D0oooo000J0?ooo`030000003oool0oooo0?l0oooo103oool001X0oooo00<000000?oo
o`3oool0o`3oool40?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00403oool0
0`000000oooo0?ooo`3o0?ooo`h0oooo00080?ooo`80000000<0oooo0000000000000`3oool00`00
0000oooo0?ooo`030?ooo`@000000P3oool2000000@0oooo00@000000?ooo`000000oooo0P000002
0?ooo`800000m03oool000T0oooo00<000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool02P000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`030000003oool0oooo0?<0oooo000:0?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo0?<0oooo00080?ooo`800000
00<0oooo0000000000002@3oool3000000<0oooo0P0000020?ooo`<0000000<0oooo000000000000
1000003f0?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo000G0?ooo`800000o`3oool8
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00225805, -0.0163921, \
8.48801*^-05, 0.000725423}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
This looks reasonable -- intially the block moves in the z-direction, but \
gravity pulls it down the plane in the x-direction.  Friction modifies this.  \


Now let's plot the approximate solution from class.  Note that v_z(0)/v(0) = \
1 and v_x(0)=0 for our initial conditions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g = 9.8;\)\), "\n", 
    \(\(muk = 0.3;\)\), "\n", 
    \(\(theta = 30.  Degree;\)\), "\n", 
    \(p2 = 
      ParametricPlot[{\(-g\)/2*muk*Cos[theta]*t^2 + 0.2*t, 
          g/2*Sin[theta]*t^2}, {t, 0, 0.25}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.592125 48.8939 0.0147151 3.84394 [
[.10319 .00222 -15 -9 ]
[.10319 .00222 15 0 ]
[.34765 .00222 -18 -9 ]
[.34765 .00222 18 0 ]
[.83659 .00222 -15 -9 ]
[.83659 .00222 15 0 ]
[.57962 .11081 -30 -4.5 ]
[.57962 .11081 0 4.5 ]
[.57962 .20691 -24 -4.5 ]
[.57962 .20691 0 4.5 ]
[.57962 .30301 -30 -4.5 ]
[.57962 .30301 0 4.5 ]
[.57962 .39911 -18 -4.5 ]
[.57962 .39911 0 4.5 ]
[.57962 .49521 -30 -4.5 ]
[.57962 .49521 0 4.5 ]
[.57962 .59131 -24 -4.5 ]
[.57962 .59131 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10319 .01472 m
.10319 .02097 L
s
[(-0.01)] .10319 .00222 0 1 Mshowa
.34765 .01472 m
.34765 .02097 L
s
[(-0.005)] .34765 .00222 0 1 Mshowa
.83659 .01472 m
.83659 .02097 L
s
[(0.005)] .83659 .00222 0 1 Mshowa
.125 Mabswid
.15208 .01472 m
.15208 .01847 L
s
.20097 .01472 m
.20097 .01847 L
s
.24987 .01472 m
.24987 .01847 L
s
.29876 .01472 m
.29876 .01847 L
s
.39655 .01472 m
.39655 .01847 L
s
.44544 .01472 m
.44544 .01847 L
s
.49434 .01472 m
.49434 .01847 L
s
.54323 .01472 m
.54323 .01847 L
s
.64102 .01472 m
.64102 .01847 L
s
.68991 .01472 m
.68991 .01847 L
s
.73881 .01472 m
.73881 .01847 L
s
.7877 .01472 m
.7877 .01847 L
s
.05429 .01472 m
.05429 .01847 L
s
.0054 .01472 m
.0054 .01847 L
s
.88549 .01472 m
.88549 .01847 L
s
.93438 .01472 m
.93438 .01847 L
s
.98328 .01472 m
.98328 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.59212 .11081 m
.59837 .11081 L
s
[(0.025)] .57962 .11081 1 0 Mshowa
.59212 .20691 m
.59837 .20691 L
s
[(0.05)] .57962 .20691 1 0 Mshowa
.59212 .30301 m
.59837 .30301 L
s
[(0.075)] .57962 .30301 1 0 Mshowa
.59212 .39911 m
.59837 .39911 L
s
[(0.1)] .57962 .39911 1 0 Mshowa
.59212 .49521 m
.59837 .49521 L
s
[(0.125)] .57962 .49521 1 0 Mshowa
.59212 .59131 m
.59837 .59131 L
s
[(0.15)] .57962 .59131 1 0 Mshowa
.125 Mabswid
.59212 .03393 m
.59587 .03393 L
s
.59212 .05315 m
.59587 .05315 L
s
.59212 .07237 m
.59587 .07237 L
s
.59212 .09159 m
.59587 .09159 L
s
.59212 .13003 m
.59587 .13003 L
s
.59212 .14925 m
.59587 .14925 L
s
.59212 .16847 m
.59587 .16847 L
s
.59212 .18769 m
.59587 .18769 L
s
.59212 .22613 m
.59587 .22613 L
s
.59212 .24535 m
.59587 .24535 L
s
.59212 .26457 m
.59587 .26457 L
s
.59212 .28379 m
.59587 .28379 L
s
.59212 .32223 m
.59587 .32223 L
s
.59212 .34145 m
.59587 .34145 L
s
.59212 .36067 m
.59587 .36067 L
s
.59212 .37989 m
.59587 .37989 L
s
.59212 .41833 m
.59587 .41833 L
s
.59212 .43755 m
.59587 .43755 L
s
.59212 .45677 m
.59587 .45677 L
s
.59212 .47599 m
.59587 .47599 L
s
.59212 .51443 m
.59587 .51443 L
s
.59212 .53365 m
.59587 .53365 L
s
.59212 .55287 m
.59587 .55287 L
s
.59212 .57209 m
.59587 .57209 L
s
.59212 .61053 m
.59587 .61053 L
s
.25 Mabswid
.59212 0 m
.59212 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.59212 .01472 m
.59514 .01472 L
.59787 .01472 L
.60101 .01472 L
.60396 .01473 L
.60919 .01474 L
.61482 .01477 L
.62097 .0148 L
.62744 .01484 L
.63889 .01494 L
.6505 .01508 L
.6612 .01523 L
.6849 .01568 L
.70811 .01629 L
.72851 .01697 L
.77148 .01895 L
.80551 .02117 L
.83913 .02413 L
.86764 .02746 L
.89437 .03156 L
.91777 .03634 L
.93622 .04138 L
.95112 .04692 L
.96177 .05249 L
.96621 .0556 L
.96961 .05861 L
.97254 .06204 L
.9738 .06402 L
.97472 .06586 L
.97539 .06763 L
.97565 .06853 L
.97588 .06954 L
.97602 .0704 L
.97608 .07089 L
.97613 .07134 L
.97616 .07173 L
.97618 .07217 L
.97619 .07263 L
.97619 .07305 L
.97618 .07356 L
.97616 .07385 L
.97615 .07411 L
.9761 .0746 L
.97604 .07512 L
.97591 .07602 L
.97571 .07702 L
.97507 .07927 L
.97424 .08141 L
.97187 .08581 L
.96876 .09012 L
Mistroke
.96066 .09854 L
.94873 .10806 L
.93465 .11733 L
.89498 .13855 L
.83841 .16328 L
.76982 .18924 L
.69079 .21619 L
.59272 .24697 L
.4846 .27869 L
.36797 .3111 L
.23019 .34767 L
.0843 .38487 L
Mfstroke
.0843 .38487 m
0 .40563 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00703oool2000000@0oooo0P0000040?ooo`8000000`3oool5000002T0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P0000040?ooo`800000J@3oool2000000@0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P00000X0?ooo`006`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00001W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo000K0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0X0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo06D0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool09@3oool0
01D0oooo100000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0R0?ooo`@000000P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool2000006P0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
0P00000X0?ooo`006`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`1W0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo02L0oooo000L0?ooo`8000002P3oool2000000@0oooo0P00000[0?ooo`80
00002P3oool2000000@0oooo0P0000040?ooo`<00000J03oool2000000X0oooo0P0000040?ooo`80
0000103oool3000002L0oooo003o0?ooob40oooo002X0?ooo`030000003oool0oooo07D0oooo002X
0?ooo`030000003oool0oooo07D0oooo002X0?ooo`030000003oool0oooo07D0oooo002X0?ooo`03
0000003oool0oooo07D0oooo00070?ooool000004P0000080?ooo`00203oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3ooolC000000d0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo03<0oooo2@0000040?ooo`030000003oool0oooo0380oooo002X0?oo
o`030000003oool0oooo03`0oooo3P00000[0?ooo`00Z03oool00`000000oooo0?ooo`1:0?ooo`@0
00009`3oool00:P0oooo0P00001?0?ooo`D000008P3oool00:P0oooo00<000000?ooo`3oool0D`3o
ool6000001`0oooo002X0?ooo`030000003oool0oooo05T0oooo0`00000I0?ooo`00Z03oool00`00
0000oooo0?ooo`1L0?ooo`8000005`3oool00:P0oooo00<000000?ooo`3oool0GP3oool3000001@0
oooo002X0?ooo`800000HP3oool200000180oooo002X0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool03`3oool00:P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0>
0?ooo`00Z03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00d0oooo002X0?ooo`03
0000003oool0oooo06D0oooo0P00000>0?ooo`00Z03oool00`000000oooo0?ooo`1V0?ooo`030000
003oool0oooo00`0oooo002X0?ooo`800000I`3oool00`000000oooo0?ooo`0<0?ooo`00Z03oool0
0`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00`0oooo002X0?ooo`030000003oool0oooo
06D0oooo0P00000>0?ooo`00Z03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00d0
oooo002X0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool03P3oool00:P0oooo0P00
001U0?ooo`030000003oool0oooo00h0oooo002X0?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool03`3oool00:P0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0@0?oo
o`00R@3oool2000000@0oooo0P0000040?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`03
0000003oool0oooo0600oooo0P00000C0?ooo`00R03oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo05h0oooo0P00000E0?ooo`00R03oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`<00000G@3oool00`000000oooo0?ooo`0E0?ooo`00R03oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000D0oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0F0?ooo`00R03oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool05`3oool008T0
oooo0P00000:0?ooo`800000103oool2000000@0oooo0`0000040?ooo`030000003oool0oooo05T0
oooo0P00000J0?ooo`00Z03oool00`000000oooo0?ooo`1G0?ooo`800000703oool00:P0oooo0P00
001F0?ooo`8000007P3oool00:P0oooo00<000000?ooo`3oool0D`3oool200000200oooo002X0?oo
o`030000003oool0oooo0540oooo0P00000R0?ooo`00Z03oool00`000000oooo0?ooo`1?0?ooo`80
0000903oool00:P0oooo00<000000?ooo`3oool0C@3oool2000002H0oooo002X0?ooo`030000003o
ool0oooo04X0oooo0`00000X0?ooo`00Z03oool2000004P0oooo0`00000[0?ooo`00Z03oool00`00
0000oooo0?ooo`150?ooo`800000;P3oool00:P0oooo00<000000?ooo`3oool0@P3oool300000300
oooo002X0?ooo`030000003oool0oooo03l0oooo0`00000c0?ooo`00Z03oool00`000000oooo0?oo
o`0m0?ooo`800000=P3oool00:P0oooo0P00000l0?ooo`800000>03oool00:P0oooo00<000000?oo
o`3oool0>@3oool2000003X0oooo002X0?ooo`030000003oool0oooo03H0oooo0`00000l0?ooo`00
Z03oool00`000000oooo0?ooo`0d0?ooo`800000?`3oool00:P0oooo00<000000?ooo`3oool0<P3o
ool200000440oooo002X0?ooo`800000<@3oool2000004<0oooo002X0?ooo`030000003oool0oooo
02d0oooo0`0000150?ooo`00Z03oool00`000000oooo0?ooo`0Z0?ooo`<00000B03oool008l0oooo
0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo02L0oooo
0`00001;0?ooo`00SP3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0T0?ooo`<00000CP3oool008h0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo0080oooo0`00000P0?ooo`@00000D@3oool008h0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000oooo0?ooo`0M0?ooo`<00000E@3o
ool008h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool3000005P0oooo002?0?ooo`8000002P3o
ool2000000@0oooo0`0000040?ooo`030000003oool0oooo01L0oooo0`00001K0?ooo`00Z03oool0
0`000000oooo0?ooo`0C0?ooo`@00000GP3oool00:P0oooo00<000000?ooo`3oool0403oool30000
0680oooo002X0?ooo`8000003P3oool3000006D0oooo002X0?ooo`030000003oool0oooo00T0oooo
1000001X0?ooo`00Z03oool00`000000oooo0?ooo`060?ooo`<00000K03oool00:P0oooo00<00000
0?ooo`3oool00`3oool3000006l0oooo002X0?ooo`030000003oool0000000<00000LP3oool00:L0
oooo0`00001f0?ooo`00Y03oool3000000030?ooo`000000oooo07H0oooo002P0?ooo`@00000103o
ool00`000000oooo0?ooo`1e0?ooo`00W@3oool3000000P0oooo00<000000?ooo`3oool0M@3oool0
09X0oooo0`00000;0?ooo`030000003oool0oooo07D0oooo002G0?ooo`<000003P3oool2000007H0
oooo002D0?ooo`<000004@3oool00`000000oooo0?ooo`1e0?ooo`00T03oool4000001@0oooo00<0
00000?ooo`3oool0M@3oool008d0oooo0`00000H0?ooo`030000003oool0oooo07D0oooo002:0?oo
o`<000006`3oool00`000000oooo0?ooo`1e0?ooo`00QP3oool4000001h0oooo0P00001f0?ooo`00
P`3oool300000280oooo00<000000?ooo`3oool0M@3oool007l0oooo1000000U0?ooo`030000003o
ool0oooo07D0oooo001l0?ooo`<00000:@3oool00`000000oooo0?ooo`1e0?ooo`00N03oool40000
00d0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool00P3oool20000
00D0oooo00<000000?ooo`3oool0M@3oool007@0oooo1000000@0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1e0?ooo`00L@3oool3000001@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool3000007D0oooo001]0?ooo`@000005`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool0oooo0P0000050?oo
o`030000003oool0oooo07D0oooo001Z0?ooo`<000006`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo07D0oooo001V0?ooo`@000007`3oool2000000X0oooo0P000003
0?ooo`@000000`3oool3000000@0oooo00<000000?ooo`3oool0M@3oool00680oooo100000120?oo
o`030000003oool0oooo07D0oooo001N0?ooo`@00000AP3oool2000007H0oooo001J0?ooo`@00000
BP3oool00`000000oooo0?ooo`1e0?ooo`00E`3oool3000004h0oooo00<000000?ooo`3oool0M@3o
ool005<0oooo1000001A0?ooo`030000003oool0oooo07D0oooo001?0?ooo`@00000E@3oool00`00
0000oooo0?ooo`1e0?ooo`00B`3oool4000005T0oooo0P00001f0?ooo`00A`3oool4000005d0oooo
00<000000?ooo`3oool0M@3oool004@0oooo0`00001Q0?ooo`030000003oool0oooo07D0oooo0010
0?ooo`@00000I03oool00`000000oooo0?ooo`1e0?ooo`00?03oool4000006P0oooo00<000000?oo
o`3oool0M@3oool003P0oooo1000001/0?ooo`800000MP3oool003@0oooo1000001`0?ooo`030000
003oool0oooo07D0oooo000`0?ooo`@00000M03oool00`000000oooo0?ooo`1e0?ooo`00;03oool4
000007P0oooo00<000000?ooo`3oool0M@3oool002P0oooo1000001l0?ooo`030000003oool0oooo
07D0oooo000T0?ooo`@00000P03oool00`000000oooo0?ooo`1e0?ooo`00803oool4000008@0oooo
0P00001f0?ooo`007@3oool3000008P0oooo00<000000?ooo`3oool0M@3oool001T0oooo1000002;
0?ooo`030000003oool0oooo07D0oooo000E0?ooo`@00000O03oool2000000@0oooo0P0000030?oo
o`D000000`3oool00`000000oooo0?ooo`1e0?ooo`004@3oool4000007l0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07D0oooo000=0?ooo`@0
0000P`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo0`00001e0?oo
o`002@3oool4000008L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo07D0oooo00070?ooo`800000R`3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0M@3oool009D0oooo0P00000:0?ooo`80
00001@3oool00`000000oooo0?ooo`1e0?ooo`00Z03oool00`000000oooo0?ooo`1e0?ooo`00Z03o
ool2000007H0oooo002X0?ooo`030000003oool0oooo07D0oooo002X0?ooo`030000003oool0oooo
07D0oooo002X0?ooo`030000003oool0oooo07D0oooo002X0?ooo`030000003oool0oooo07D0oooo
002X0?ooo`800000MP3oool00:P0oooo00<000000?ooo`3oool0M@3oool00:P0oooo00<000000?oo
o`3oool0M@3oool00:P0oooo00<000000?ooo`3oool0M@3oool00:P0oooo00<000000?ooo`3oool0
M@3oool00:P0oooo00<000000?ooo`3oool0M@3oool00:P0oooo0P00001f0?ooo`00Z03oool00`00
0000oooo0?ooo`1e0?ooo`00Z03oool00`000000oooo0?ooo`1e0?ooo`00Z03oool00`000000oooo
0?ooo`1e0?ooo`00Z03oool00`000000oooo0?ooo`1e0?ooo`00Z03oool2000007H0oooo002X0?oo
o`030000003oool0oooo07D0oooo002X0?ooo`030000003oool0oooo07D0oooo00290?ooo`800000
103oool2000000<0oooo1@0000000`3oool0000000000002000000<0oooo0P0000050?ooo`030000
003oool0oooo07D0oooo00280?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0
oooo000000050?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0M@3oool008P0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool3000007D0oooo00280?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`00
0000oooo0?ooo`1e0?ooo`00R03oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0M@3o
ool008T0oooo0P00000:0?ooo`800000103oool2000000@0oooo0`0000040?ooo`030000003oool0
oooo07D0oooo002X0?ooo`030000003oool0oooo07D0oooo002X0?ooo`800000MP3oool00:P0oooo
00<000000?ooo`3oool0M@3oool00:P0oooo00<000000?ooo`3oool0M@3oool00:P0oooo00<00000
0?ooo`3oool0M@3oool00:P0oooo00<000000?ooo`3oool0M@3oool00:P0oooo0P00001f0?ooo`00
Z03oool00`000000oooo0?ooo`1e0?ooo`00Z03oool00`000000oooo0?ooo`1e0?ooo`00Z03oool0
0`000000oooo0?ooo`1e0?ooo`00Z03oool00`000000oooo0?ooo`1e0?ooo`00Z03oool00`000000
oooo0?ooo`1e0?ooo`00Z03oool2000007H0oooo002X0?ooo`030000003oool0oooo07D0oooo002X
0?ooo`030000003oool0oooo07D0oooo002X0?ooo`030000003oool0oooo07D0oooo002X0?ooo`03
0000003oool0oooo07D0oooo002X0?ooo`800000MP3oool00:P0oooo00<000000?ooo`3oool0M@3o
ool00:P0oooo00<000000?ooo`3oool0M@3oool008l0oooo0P0000040?ooo`8000000`3oool50000
0080oooo0P0000050?ooo`030000003oool0oooo07D0oooo002>0?ooo`040000003oool0oooo0000
00X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0M@3oool008h0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo0`00001e0?ooo`00SP3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo07D0oooo002>0?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo07D0oooo002?0?ooo`8000002P3oool2000000@0oooo0`0000040?oo
o`030000003oool0oooo07D0oooo002X0?ooo`030000003oool0oooo07D0oooo002X0?ooo`800000
MP3oool00:P0oooo00<000000?ooo`3oool0M@3oool00:P0oooo00<000000?ooo`3oool0M@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0126464, -0.011837, \
7.49978*^-05, 0.000953953}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Wow!  That friction force overwelms gravity in a hurry...very unphysical in a \
short time.
Let's over lay them.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[p1, p2]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.421174 32.9849 0.0147151 6.62272 [
[.09132 .00222 -15 -9 ]
[.09132 .00222 15 0 ]
[.25625 .00222 -18 -9 ]
[.25625 .00222 18 0 ]
[.5861 .00222 -15 -9 ]
[.5861 .00222 15 0 ]
[.75102 .00222 -12 -9 ]
[.75102 .00222 12 0 ]
[.91595 .00222 -15 -9 ]
[.91595 .00222 15 0 ]
[1.025 .01472 0 -7.5 ]
[1.025 .01472 52 7.5 ]
[.40867 .14717 -24 -4.5 ]
[.40867 .14717 0 4.5 ]
[.40867 .27962 -24 -4.5 ]
[.40867 .27962 0 4.5 ]
[.40867 .41208 -24 -4.5 ]
[.40867 .41208 0 4.5 ]
[.40867 .54453 -24 -4.5 ]
[.40867 .54453 0 4.5 ]
[.42117 .64303 -20 0 ]
[.42117 .64303 20 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.09132 .01472 m
.09132 .02097 L
s
[(-0.01)] .09132 .00222 0 1 Mshowa
.25625 .01472 m
.25625 .02097 L
s
[(-0.005)] .25625 .00222 0 1 Mshowa
.5861 .01472 m
.5861 .02097 L
s
[(0.005)] .5861 .00222 0 1 Mshowa
.75102 .01472 m
.75102 .02097 L
s
[(0.01)] .75102 .00222 0 1 Mshowa
.91595 .01472 m
.91595 .02097 L
s
[(0.015)] .91595 .00222 0 1 Mshowa
.125 Mabswid
.12431 .01472 m
.12431 .01847 L
s
.15729 .01472 m
.15729 .01847 L
s
.19028 .01472 m
.19028 .01847 L
s
.22326 .01472 m
.22326 .01847 L
s
.28923 .01472 m
.28923 .01847 L
s
.32222 .01472 m
.32222 .01847 L
s
.3552 .01472 m
.3552 .01847 L
s
.38819 .01472 m
.38819 .01847 L
s
.45416 .01472 m
.45416 .01847 L
s
.48714 .01472 m
.48714 .01847 L
s
.52013 .01472 m
.52013 .01847 L
s
.55311 .01472 m
.55311 .01847 L
s
.61908 .01472 m
.61908 .01847 L
s
.65207 .01472 m
.65207 .01847 L
s
.68505 .01472 m
.68505 .01847 L
s
.71804 .01472 m
.71804 .01847 L
s
.78401 .01472 m
.78401 .01847 L
s
.81699 .01472 m
.81699 .01847 L
s
.84998 .01472 m
.84998 .01847 L
s
.88296 .01472 m
.88296 .01847 L
s
.05834 .01472 m
.05834 .01847 L
s
.02535 .01472 m
.02535 .01847 L
s
.94893 .01472 m
.94893 .01847 L
s
.98192 .01472 m
.98192 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
69.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(accros) show
111.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.42117 .14717 m
.42742 .14717 L
s
[(0.02)] .40867 .14717 1 0 Mshowa
.42117 .27962 m
.42742 .27962 L
s
[(0.04)] .40867 .27962 1 0 Mshowa
.42117 .41208 m
.42742 .41208 L
s
[(0.06)] .40867 .41208 1 0 Mshowa
.42117 .54453 m
.42742 .54453 L
s
[(0.08)] .40867 .54453 1 0 Mshowa
.125 Mabswid
.42117 .04783 m
.42492 .04783 L
s
.42117 .08094 m
.42492 .08094 L
s
.42117 .11406 m
.42492 .11406 L
s
.42117 .18028 m
.42492 .18028 L
s
.42117 .2134 m
.42492 .2134 L
s
.42117 .24651 m
.42492 .24651 L
s
.42117 .31274 m
.42492 .31274 L
s
.42117 .34585 m
.42492 .34585 L
s
.42117 .37896 m
.42492 .37896 L
s
.42117 .44519 m
.42492 .44519 L
s
.42117 .47831 m
.42492 .47831 L
s
.42117 .51142 m
.42492 .51142 L
s
.42117 .57765 m
.42492 .57765 L
s
.42117 .61076 m
.42492 .61076 L
s
.25 Mabswid
.42117 0 m
.42117 .61803 L
s
gsave
.42117 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(down) show
99.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.42117 .01472 m
.4232 .01472 L
.42505 .01472 L
.42716 .01473 L
.42916 .01474 L
.43268 .01477 L
.43648 .0148 L
.44063 .01486 L
.445 .01493 L
.45272 .0151 L
.46056 .01533 L
.46778 .01558 L
.48378 .01631 L
.49948 .01727 L
.51331 .01834 L
.54263 .02134 L
.56619 .02458 L
.59003 .02875 L
.63179 .03867 L
.66675 .05025 L
.69939 .06457 L
.72729 .08027 L
.75144 .09709 L
.77475 .1168 L
.79524 .13752 L
.81341 .15906 L
.83132 .18372 L
.84736 .20912 L
.86328 .23792 L
.87765 .26741 L
.89067 .2974 L
.90375 .33105 L
.91568 .36514 L
.92659 .39948 L
.93765 .43773 L
.94781 .47619 L
.95812 .51885 L
.96763 .56166 L
.97619 .60332 L
s
.42117 .01472 m
.42321 .01472 L
.42505 .01472 L
.42717 .01472 L
.42916 .01473 L
.43269 .01474 L
.43649 .01476 L
.44064 .01479 L
.445 .01482 L
.45272 .01491 L
.46056 .01502 L
.46777 .01514 L
.48376 .01552 L
.49942 .01602 L
.51318 .01658 L
.54217 .01822 L
.56513 .02006 L
.58781 .02251 L
.60704 .02527 L
.62508 .02866 L
.64086 .03261 L
.65331 .03678 L
.66336 .04137 L
.67055 .04598 L
.67354 .04855 L
.67584 .05105 L
.67781 .05389 L
.67866 .05552 L
.67928 .05705 L
.67973 .05851 L
.67991 .05926 L
.68006 .06009 L
.68016 .0608 L
.6802 .06121 L
.68023 .06158 L
.68025 .06191 L
.68027 .06227 L
.68027 .06265 L
.68027 .063 L
.68026 .06342 L
.68025 .06365 L
.68024 .06387 L
.68021 .06428 L
.68018 .06471 L
.68008 .06546 L
.67995 .06629 L
.67952 .06815 L
.67896 .06992 L
.67736 .07356 L
.67526 .07712 L
Mistroke
.6698 .0841 L
.66175 .09197 L
.65225 .09965 L
.62549 .11721 L
.58732 .13768 L
.54105 .15916 L
.48774 .18147 L
.42158 .20694 L
.34863 .23319 L
.26995 .26002 L
.17701 .29028 L
.07858 .32108 L
Mfstroke
.07858 .32108 m
0 .34482 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000?Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05000A
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0b
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0B
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05000AOol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`050002Ool00`00Oomoo`12Ool000ioo`03001oo`0000Moo`03001oo`0000=o
o`03001oogoo011oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`00039o
o`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`00019oo`03001oo`0000Mo
o`03001oo`0000=oo`03001oogoo011oo`03001oo`0000Moo`03001oo`0000=oo`07001oogooOol0
07oo0000@goo0009Ool30002Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0;Ool30002
Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`0`Ool00`00Ool00007
Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`0@Ool00`00Ool00007Ool00`00Ool00003
Ool00`00Oomoo`0@Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`11
Ool000ioo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo011oo`03001oo`0000Moo`03001o
o`00009oo`03001oo`00009oo`8003=oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009o
o`8001=oo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo011oo`03001oo`0000Moo`03001o
o`0000=oo`04001oogooOol20014Ool000ioo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo
011oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oogoo039oo`03001oo`00
00Moo`03001oo`00009oo`03001oo`00009oo`03001oogoo019oo`03001oo`0000Moo`03001oo`00
00=oo`03001oogoo011oo`03001oo`0000Moo`03001oo`0000=oo`05001oogooOol00015Ool000mo
o`03001oogoo00Moo`04001oogooOol2000COol00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomo
ogoo0`00<goo00<007ooOol01goo00<007ooOol00Woo00@007ooOomoo`<001=oo`03001oogoo00Mo
o`04001oogooOol2000COol00`00Oomoo`07Ool01000Oomoogoo0P000goo0`00@goo003oOolQOol0
061oo`03001oogoo099oo`03001oogoo02Qoo`00H7oo00<007ooOol0Rgoo10000goo00<007ooOol0
0Woo100000Aoo`000000009oo`<0009oo`<000=oo`80009oo`8000]oo`00H7oo00<007ooOol0S7oo
00<007oo000017oo00@007ooOomoo`<0009oo`03001oogoo009oo`03001oogoo00=oo`05001oogoo
Ool00002Ool01@00Oomoogoo00002Woo003V0008Ool00`00Ool0000;Ool01000Oomoo`0017oo00<0
07ooOol00goo00D007ooOomoo`00009oo`04001oogoo000;Ool000Eoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00AooaP000Moo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Yo
o`@000Uoo`80009oo`<0009oo`<0009oo`@0009oo`8000=oo`8000Yoo`0057oo00<007ooOol08goo
00<007ooOol08goo00<007ooOol05Woo40008goo00<007ooOol08Woo00<007ooOol0C7oo001POol0
0`00Oomoo`0LOol50005Ool4002COol0061oo`03001oogoo025oo`H000=oo`@008moo`00H7oo00<0
07ooOol09goo10000goo1@00RWoo001POol00`00Oomoo`0[Ool40004Ool20028Ool0061oo`03001o
ogoo02moo`8000Aoo`03001oogoo08Eoo`00H7oo0P00<Woo0`000Woo0P00QGoo001POol00`00Oomo
o`0dOol50024Ool0061oo`03001oogoo03Moo`8008Aoo`00H7oo00<007ooOol0>7oo1000PGoo001P
Ool00`00Oomoo`0hOol01000Oomoogoo0P00Ogoo001POol00`00Oomoo`0hOol00`00Oomoo`03Ool2
001mOol0061oo`03001oogoo03Qoo`03001oogoo00Eoo`8007]oo`00H7oo00<007ooOol0=goo00<0
07ooOol027oo0P00NGoo001POol2000gOol00`00Oomoo`0;Ool2001gOol0061oo`03001oogoo03Eo
o`03001oogoo00ioo`03001oogoo07Aoo`00H7oo00<007ooOol0=7oo00<007ooOol047oo0P00M7oo
001POol00`00Oomoo`0cOol00`00Oomoo`0COol00`00Oomoo`1aOol0061oo`03001oogoo039oo`03
001oogoo01Eoo`03001oogoo071oo`00H7oo00<007ooOol0<7oo0P006Goo00<007ooOol0Kgoo001P
Ool00`00Oomoo`0_Ool00`00Oomoo`0JOol00`00Oomoo`1^Ool0061oo`8002ioo`8001ioo`03001o
ogoo06eoo`00H7oo00<007ooOol0;7oo00<007ooOol07goo00<007ooOol0K7oo001POol00`00Oomo
o`0ZOol2000SOol00`00Oomoo`1[Ool0061oo`03001oogoo02Qoo`8002Ioo`03001oogoo06Yoo`00
H7oo00<007ooOol09Woo0P00:Goo00<007ooOol0JGoo001POol00`00Oomoo`0TOol2000/Ool00`00
Oomoo`1XOol004]oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol30004Ool00`00Oomo
o`0SOol00`00Oomoo`0]Ool00`00Oomoo`1WOol004Yoo`03001oo`0000Moo`03001oo`00009oo`03
001oogoo00Aoo`03001oogoo025oo`80035oo`03001oogoo06Ioo`00BWoo00<007oo00001goo00<0
07oo00000goo00<007ooOol00goo0P0087oo0P00=7oo00<007ooOol0IGoo001:Ool00`00Ool00007
Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`0MOol2000fOol00`00Oomoo`1UOol004Yo
o`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo01]oo`8003Uoo`03001o
ogoo06Aoo`00Bgoo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol067oo
0`00?7oo00<007ooOol0Hgoo001POol00`00Oomoo`0FOol20010Ool00`00Oomoo`1ROol0061oo`03
001oogoo01=oo`<004=oo`03001oogoo065oo`00H7oo00<007ooOol047oo0`00AWoo00<007ooOol0
HGoo001POol2000?Ool2001:Ool00`00Oomoo`1POol0061oo`03001oogoo00]oo`<004eoo`03001o
ogoo05moo`00H7oo00<007ooOol02Goo0P00DGoo00<007ooOol0GWoo001POol00`00Oomoo`06Ool3
001COol00`00Oomoo`1NOol0061oo`03001oogoo00Aoo`8005Moo`03001oogoo05eoo`00H7oo00@0
07ooOomoo`<005Yoo`03001oogoo05aoo`00H7oo00@007oo000005eoo`03001oogoo05aoo`00Ggoo
0`00H7oo00<007ooOol0Fgoo001LOol300000goo0000001POol00`00Oomoo`1KOol005Uoo`<000Ao
o`03001oogoo061oo`03001oogoo05Yoo`00Egoo0P001goo00<007ooOol0H7oo00<007ooOol0FWoo
001DOol30009Ool00`00Oomoo`1QOol00`00Oomoo`1IOol0055oo`<000aoo`03001oogoo065oo`03
001oogoo05Uoo`00CWoo0`003goo00<007ooOol0HWoo00<007ooOol0F7oo001;Ool3000BOol00`00
Oomoo`1ROol00`00Oomoo`1HOol004Qoo`<001Eoo`03001oogoo06=oo`03001oogoo05Moo`00AGoo
0`0067oo0P00I7oo00<007ooOol0Egoo0012Ool3000KOol00`00Oomoo`1TOol00`00Oomoo`1FOol0
03moo`<001ioo`03001oogoo06Eoo`03001oogoo05Eoo`00?7oo0`008Goo00<007ooOol0IGoo00<0
07ooOol0EGoo000iOol3000TOol00`00Oomoo`1VOol00`00Oomoo`1DOol003Ioo`<0019oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo009oo`<000=oo`03001oogoo06Ioo`03001oogoo05Ao
o`00<goo0`0057oo00<007oo00001goo00<007oo000017oo00<007ooOol00Woo00<007ooOol0Igoo
00<007ooOol0Dgoo000`Ool3000GOol00`00Ool00007Ool00`00Ool00002Ool40003Ool2001XOol0
0`00Oomoo`1COol002eoo`<001Yoo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`03
001oogoo06Qoo`03001oogoo059oo`00:Woo0`007Goo00<007oo00001goo00<007oo00000goo0P00
17oo00<007ooOol0J7oo00<007ooOol0DWoo000WOol3000QOol00`00Oomoo`07Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`1YOol00`00Oomoo`1AOol002Aoo`<003Uoo`03001oogoo06Uo
o`03001oogoo055oo`008Goo0`00?7oo00<007ooOol0JGoo00<007ooOol0DGoo000NOol3000oOol0
0`00Oomoo`1ZOol00`00Oomoo`1@Ool001Yoo`@0049oo`03001oogoo06Yoo`03001oogoo051oo`00
5goo0`00AWoo0P00Jgoo00<007ooOol0D7oo000DOol30019Ool00`00Oomoo`1[Ool00`00Oomoo`1?
Ool0015oo`<004aoo`03001oogoo06]oo`03001oogoo04moo`003Goo1000Cgoo00<007ooOol0K7oo
00<007ooOol0CWoo000:Ool3001COol00`00Oomoo`1/Ool00`00Oomoo`1>Ool000Ioo`@005Ioo`03
001oogoo06aoo`03001oogoo04ioo`000Woo1000FWoo00<007ooOol0K7oo00<007ooOol0CWoo0002
001NOol2001^Ool00`00Oomoo`1=Ool0061oo`03001oogoo06eoo`03001oogoo04eoo`00H7oo00<0
07ooOol0KGoo00<007ooOol0CGoo001POol00`00Oomoo`1]Ool00`00Oomoo`1=Ool0061oo`03001o
ogoo06ioo`03001oogoo04aoo`00H7oo00<007ooOol0KWoo00<007ooOol0C7oo001POol00`00Oomo
o`1^Ool00`00Oomoo`1<Ool0061oo`03001oogoo06moo`03001oogoo04]oo`00H7oo0P00L7oo00<0
07ooOol0Bgoo001POol00`00Oomoo`1_Ool00`00Oomoo`1;Ool0061oo`03001oogoo071oo`03001o
ogoo04Yoo`00H7oo00<007ooOol0L7oo00<007ooOol0BWoo001POol00`00Oomoo`1aOol00`00Oomo
o`19Ool0061oo`03001oogoo075oo`03001oogoo04Uoo`00Bgoo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOomoo`8000Eoo`03001oogoo075oo`03001oogoo04Uoo`00BWoo00<007oo00001goo
00<007oo00000Woo00<007oo000017oo00<007ooOol0LGoo00<007ooOol0BGoo001:Ool00`00Ool0
0007Ool00`00Ool00002Ool00`00Ool00004Ool2001cOol00`00Oomoo`18Ool004Yoo`03001oo`00
00Moo`03001oo`00009oo`8000Eoo`03001oogoo079oo`03001oogoo04Qoo`00BWoo00<007oo0000
1goo00<007oo00000Woo00<007ooOol017oo00<007ooOol0LWoo00<007ooOol0B7oo001;Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`1bOol00`00Oomoo`18Ool0061oo`03001o
ogoo07=oo`03001oogoo04Moo`00H7oo00<007ooOol0Lgoo00<007ooOol0Agoo001POol00`00Oomo
o`1cOol00`00Oomoo`17Ool0061oo`8007Eoo`03001oogoo04Ioo`00H7oo00<007ooOol0M7oo00<0
07ooOol0AWoo001POol00`00Oomoo`1dOol00`00Oomoo`16Ool0061oo`03001oogoo07Eoo`03001o
ogoo04Eoo`00H7oo00<007ooOol0MGoo00<007ooOol0AGoo001POol00`00Oomoo`1eOol00`00Oomo
o`15Ool0061oo`03001oogoo07Ioo`03001oogoo04Aoo`00H7oo00<007ooOol0MWoo00<007ooOol0
A7oo001POol2001gOol00`00Oomoo`14Ool0061oo`03001oogoo07Ioo`03001oogoo04Aoo`00H7oo
00<007ooOol0Mgoo00<007ooOol0@goo001POol00`00Oomoo`1gOol00`00Oomoo`13Ool0061oo`03
001oogoo07Moo`03001oogoo04=oo`00H7oo00<007ooOol0Mgoo00<007ooOol0@goo001POol00`00
Oomoo`1gOol00`00Oomoo`13Ool0061oo`8007Uoo`03001oogoo049oo`00H7oo00<007ooOol0N7oo
00<007ooOol0@Woo001POol00`00Oomoo`1hOol00`00Oomoo`12Ool0061oo`03001oogoo07Qoo`03
001oogoo049oo`00H7oo00<007ooOol0N7oo00<007ooOol0@Woo001POol00`00Oomoo`1iOol00`00
Oomoo`11Ool004]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo07Uoo`03001oogoo045oo`00BWoo00<007oo00001goo00<007oo00000Woo00<007oo
000017oo00<007ooOol0NGoo00<007ooOol0@Goo001:Ool00`00Ool00007Ool00`00Ool00002Ool0
0`00Ool00004Ool2001jOol00`00Oomoo`11Ool004Yoo`03001oo`0000Moo`03001oo`0000=oo`03
001oogoo00=oo`03001oogoo07Uoo`03001oogoo045oo`00BWoo00<007oo00001goo00<007oo0000
0Woo00<007oo000017oo00<007ooOol0NWoo00<007ooOol0@7oo001;Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1jOol00`00Oomoo`10Ool0061oo`03001oogoo07Yo
o`03001oogoo041oo`00H7oo00<007ooOol0NWoo00<007ooOol0@7oo001POol00`00Oomoo`1jOol0
0`00Oomoo`10Ool0061oo`8007aoo`03001oogoo03moo`00H7oo00<007ooOol0Ngoo00<007ooOol0
?goo001POol00`00Oomoo`1kOol00`00Oomoo`0oOol0061oo`03001oogoo07]oo`03001oogoo03mo
o`00H7oo00<007ooOol0O7oo00<007ooOol0?Woo001POol00`00Oomoo`1lOol00`00Oomoo`0nOol0
061oo`03001oogoo07aoo`03001oogoo03ioo`00H7oo00<007ooOol0_Goo001POol2002nOol0061o
o`03001oogoo0;eoo`00H7oo00<007ooOol0_Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001FOol00`00Oomoo`37Ool0
04moo`04001oogoo0003Ool00`00Oomoo`03Ool30002Ool20002Ool01000Ool007oo0P000Woo00<0
07ooOol0/7oo001@Ool20005Ool01@00Oomoogoo00000Woo00<007oo00000Woo0P0000Ioo`00Ool0
07oo0002Ool00`00Oomoo`2`Ool0051oo`8000Uoo`06001oogoo001oo`000Woo0P0000Ioo`00Ool0
07oo0002Ool00`00Oomoo`2`Ool004moo`04001oogoo0009Ool30002Ool2000017oo000007oo1P00
/goo001NOol00`00Oomoo`2oOol005eoo`800<5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{83, 370}, {257.125, 80.1875}} -> {-0.0237443, 0.0430147,
   0.000132235, 0.000658603}}]
}, Open  ]],

Cell["\<\
Now look at shorter times.  They agree much better, but don't fully converge. \
 The problem is likely in where we make an additional approximation in the \
equations for DeltaXnot'' and DeltaZnot''.  We not only say that X''>>DeltaX. \
 In the expression for DeltaX and DeltaZ we also let Xnot'(t) = Xnot'(0).  \
This threw away important early-time information.  So, our approximation is \
solvable, but not terribly accurate.  You can see how numerical techniques \
have really opened the door to analyzing complex motion (and this problem \
isn't really all that complex!)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      ParametricPlot[Evaluate[{z[t], x[t]} /. nsolution], {t, 0, 0.05}, \ 
        AxesLabel -> \ {"\<z,accros\>", "\<x,down\>"}], 
      ParametricPlot[{\(-g\)/2*muk*Cos[theta]*t^2 + 0.2*t, 
          g/2*\((Sin[theta] - muk*Cos[theta])\)*t^2}, {t, 0, 0.05}]]\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 132.4 0.0147151 120.083 [
[.15621 .00222 -15 -9 ]
[.15621 .00222 15 0 ]
[.28861 .00222 -15 -9 ]
[.28861 .00222 15 0 ]
[.42101 .00222 -15 -9 ]
[.42101 .00222 15 0 ]
[.55341 .00222 -15 -9 ]
[.55341 .00222 15 0 ]
[.68581 .00222 -15 -9 ]
[.68581 .00222 15 0 ]
[.81821 .00222 -15 -9 ]
[.81821 .00222 15 0 ]
[.95061 .00222 -15 -9 ]
[.95061 .00222 15 0 ]
[1.025 .01472 0 -7.5 ]
[1.025 .01472 52 7.5 ]
[.01131 .1348 -30 -4.5 ]
[.01131 .1348 0 4.5 ]
[.01131 .25488 -30 -4.5 ]
[.01131 .25488 0 4.5 ]
[.01131 .37496 -30 -4.5 ]
[.01131 .37496 0 4.5 ]
[.01131 .49505 -30 -4.5 ]
[.01131 .49505 0 4.5 ]
[.01131 .61513 -30 -4.5 ]
[.01131 .61513 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15621 .01472 m
.15621 .02097 L
s
[(0.001)] .15621 .00222 0 1 Mshowa
.28861 .01472 m
.28861 .02097 L
s
[(0.002)] .28861 .00222 0 1 Mshowa
.42101 .01472 m
.42101 .02097 L
s
[(0.003)] .42101 .00222 0 1 Mshowa
.55341 .01472 m
.55341 .02097 L
s
[(0.004)] .55341 .00222 0 1 Mshowa
.68581 .01472 m
.68581 .02097 L
s
[(0.005)] .68581 .00222 0 1 Mshowa
.81821 .01472 m
.81821 .02097 L
s
[(0.006)] .81821 .00222 0 1 Mshowa
.95061 .01472 m
.95061 .02097 L
s
[(0.007)] .95061 .00222 0 1 Mshowa
.125 Mabswid
.05029 .01472 m
.05029 .01847 L
s
.07677 .01472 m
.07677 .01847 L
s
.10325 .01472 m
.10325 .01847 L
s
.12973 .01472 m
.12973 .01847 L
s
.18269 .01472 m
.18269 .01847 L
s
.20917 .01472 m
.20917 .01847 L
s
.23565 .01472 m
.23565 .01847 L
s
.26213 .01472 m
.26213 .01847 L
s
.31509 .01472 m
.31509 .01847 L
s
.34157 .01472 m
.34157 .01847 L
s
.36805 .01472 m
.36805 .01847 L
s
.39453 .01472 m
.39453 .01847 L
s
.44749 .01472 m
.44749 .01847 L
s
.47397 .01472 m
.47397 .01847 L
s
.50045 .01472 m
.50045 .01847 L
s
.52693 .01472 m
.52693 .01847 L
s
.57989 .01472 m
.57989 .01847 L
s
.60637 .01472 m
.60637 .01847 L
s
.63285 .01472 m
.63285 .01847 L
s
.65933 .01472 m
.65933 .01847 L
s
.71229 .01472 m
.71229 .01847 L
s
.73877 .01472 m
.73877 .01847 L
s
.76525 .01472 m
.76525 .01847 L
s
.79173 .01472 m
.79173 .01847 L
s
.84469 .01472 m
.84469 .01847 L
s
.87117 .01472 m
.87117 .01847 L
s
.89765 .01472 m
.89765 .01847 L
s
.92413 .01472 m
.92413 .01847 L
s
.97709 .01472 m
.97709 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
69.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(accros) show
111.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.02381 .1348 m
.03006 .1348 L
s
[(0.001)] .01131 .1348 1 0 Mshowa
.02381 .25488 m
.03006 .25488 L
s
[(0.002)] .01131 .25488 1 0 Mshowa
.02381 .37496 m
.03006 .37496 L
s
[(0.003)] .01131 .37496 1 0 Mshowa
.02381 .49505 m
.03006 .49505 L
s
[(0.004)] .01131 .49505 1 0 Mshowa
.02381 .61513 m
.03006 .61513 L
s
[(0.005)] .01131 .61513 1 0 Mshowa
.125 Mabswid
.02381 .03873 m
.02756 .03873 L
s
.02381 .06275 m
.02756 .06275 L
s
.02381 .08677 m
.02756 .08677 L
s
.02381 .11078 m
.02756 .11078 L
s
.02381 .15881 m
.02756 .15881 L
s
.02381 .18283 m
.02756 .18283 L
s
.02381 .20685 m
.02756 .20685 L
s
.02381 .23086 m
.02756 .23086 L
s
.02381 .2789 m
.02756 .2789 L
s
.02381 .30291 m
.02756 .30291 L
s
.02381 .32693 m
.02756 .32693 L
s
.02381 .35095 m
.02756 .35095 L
s
.02381 .39898 m
.02756 .39898 L
s
.02381 .423 m
.02756 .423 L
s
.02381 .44701 m
.02756 .44701 L
s
.02381 .47103 m
.02756 .47103 L
s
.02381 .51906 m
.02756 .51906 L
s
.02381 .54308 m
.02756 .54308 L
s
.02381 .5671 m
.02756 .5671 L
s
.02381 .59111 m
.02756 .59111 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
75.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(down) show
99.000000 14.625000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02544 .01472 L
.02692 .01473 L
.02864 .01473 L
.03025 .01474 L
.03316 .01476 L
.03624 .01479 L
.03963 .01483 L
.04275 .01488 L
.04978 .01501 L
.05646 .01518 L
.06269 .01537 L
.07682 .01593 L
.09112 .01667 L
.10412 .01751 L
.13306 .01992 L
.15787 .02262 L
.18456 .02618 L
.23578 .03501 L
.28368 .04576 L
.33307 .05953 L
.37922 .07501 L
.42232 .09189 L
.46679 .1119 L
.50831 .13313 L
.54706 .15529 L
.58709 .18072 L
.62446 .20692 L
.663 .23659 L
.69899 .26689 L
.73262 .29758 L
.76736 .33188 L
.79984 .36646 L
.83021 .40111 L
.86167 .43951 L
.89111 .4779 L
.92157 .52023 L
.95011 .56246 L
.97619 .60332 L
s
.02381 .01472 m
.02544 .01472 L
.02693 .01472 L
.02864 .01472 L
.03026 .01472 L
.03313 .01473 L
.03625 .01475 L
.03968 .01477 L
.0433 .01479 L
.04979 .01485 L
.05647 .01493 L
.0627 .01503 L
.07683 .0153 L
.09113 .01566 L
.10413 .01607 L
.13307 .01726 L
.15787 .01859 L
.18456 .02037 L
.23574 .02483 L
.28357 .03034 L
.33284 .0375 L
.37879 .04567 L
.4216 .05472 L
.46561 .06561 L
.50652 .07734 L
.54449 .08976 L
.58345 .10422 L
.6195 .11934 L
.65629 .13671 L
.69023 .1547 L
.72148 .17317 L
.75324 .19408 L
.78235 .21544 L
.80899 .23711 L
.83591 .2614 L
.86039 .28597 L
.8849 .31338 L
.90702 .34102 L
.92643 .36804 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00<7oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol01@0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Oomoo`<000Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20006
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30003Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P001Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0>7oo000_Ool00`00Ool0
0007Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Ool00007Ool00`00Ool0
0002Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool0
0004Ool00`00Oomoo`02Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00004Ool01`00Oomo
ogoo001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`03001oo`0000Mo
o`03001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`03001oo`0000Moo`03001oo`00009o
o`03001oo`0000=oo`03001oogoo03Qoo`00;goo00<007oo00001goo00<007oo00000Woo00<007oo
00000goo00<007ooOol00goo00<007oo00001goo00<007oo00000Woo00<007oo00000goo00<007oo
Ool00goo00<007oo00001goo00<007oo00000Woo00<007oo00000goo00<007ooOol00goo00<007oo
00001goo00<007oo00000Woo00<007oo00000Woo10000Woo00<007oo00001goo00<007oo00000Woo
00<007oo000017oo00<007ooOol00Woo00<007oo00001goo00<007oo00000Woo00<007oo00000Woo
00<007oo000017oo00<007oo00001goo00<007oo00000Woo00<007oo00000goo00<007ooOol0>7oo
000_Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Ool0
0007Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Ool00007Ool00`00Ool0
0002Ool00`00Ool00004Ool00`00Oomoo`02Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool0
0002Ool00`00Ool00003Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool20005Ool0
0`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool20005Ool00`00Ool00007Ool00`00Ool0
0002Ool00`00Ool00004Ool00`00Oomoo`0gOol002moo`03001oo`0000Moo`03001oo`00009oo`03
001oo`0000=oo`03001oogoo00=oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03
001oo`0000Aoo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`03
001oo`0000Moo`03001oo`00009oo`03001oo`0000=oo`8000=oo`03001oo`0000Moo`03001oo`00
009oo`03001oo`00009oo`03001oogoo00Aoo`03001oo`0000Moo`03001oo`00009oo`03001oo`00
009oo`03001oogoo00Aoo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`00
03Uoo`00<7oo00<007ooOol01goo00<007ooOol00Woo00@007ooOomoo`8000Ioo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`04001oogooOol30005Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
1000Oomoogoo0`00>Goo003oOolQOol00?moob5oo`0087oo00<007ooOol0dWoo00<007ooOol0:7oo
000POol00`00Oomoo`3;Ool40003Ool00`00Oomoo`02Ool4000017oo000000000Woo0`000Woo0`00
0goo0P000Woo0P002goo000POol00`00Oomoo`3<Ool00`00Ool00004Ool01000Oomoogoo0`000Woo
00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`00009oo`05001oogooOol0000:Ool001]o
ol/000Qoo`03001oo`0000]oo`04001oogoo0004Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo
00@007ooOol000]oo`0087oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool0500017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02Woo1000
2Goo0P000Woo0`000Woo0`000Woo10000Woo0P000goo0P002Woo000POol00`00Oomoo`0KOol60002
Ool:003@Ool0021oo`03001oogoo025oo`D000Moo`X00<Ioo`0087oo00<007ooOol09Woo1@0037oo
2000_Woo000POol2000/Ool5000?Ool4002jOol0021oo`03001oogoo031oo`@000moo`@00;Ioo`00
87oo00<007ooOol0=7oo0`0047oo1000/Woo000POol00`00Oomoo`0gOol4000@Ool5002]Ool0021o
o`8003aoo`<0019oo`@00:Uoo`0087oo00<007ooOol0?Woo0`004goo1@00Y7oo000POol00`00Oomo
o`11Ool3000EOol4002POol0021oo`03001oogoo04Aoo`<001Ioo`@009aoo`0087oo00<007ooOol0
Agoo0`005goo0P00VWoo000POol2001;Ool3000FOol2002HOol0021oo`03001oogoo04eoo`<001Eo
o`<009Eoo`0087oo00<007ooOol0D7oo0P005Woo0P00Tgoo000POol00`00Oomoo`1BOol2000FOol3
002@Ool0021oo`03001oogoo05Aoo`8001Moo`<008eoo`0087oo0P00Egoo0P0067oo0P00Rgoo000P
Ool00`00Oomoo`1HOol2000HOol20029Ool0021oo`03001oogoo05Yoo`03001oogoo01Moo`<008Io
o`001goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01@000Woo00<0
07ooOol0Fgoo0P006Woo0P00Q7oo0006Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00003
Ool00`00Oomoo`02Ool00`00Oomoo`1MOol2000JOol30021Ool000Ioo`03001oo`0000Moo`03001o
o`00009oo`03001oo`0000=oo`03001oogoo009oo`80061oo`03001oogoo01Yoo`8007moo`001Woo
00<007oo00001goo00<007oo00000Woo00<007oo00000goo00<007ooOol00Woo00<007ooOol0H7oo
0P0077oo0P00OGoo0006Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomo
o`02Ool00`00Oomoo`1ROol2000LOol2001kOol000Moo`03001oogoo00Moo`03001oogoo009oo`04
001oogooOol20004Ool00`00Oomoo`1TOol2000LOol2001iOol0021oo`03001oogoo06Ioo`8001ao
o`03001oogoo07Ioo`0087oo0P00JGoo0P006goo0P00MWoo000POol00`00Oomoo`1ZOol00`00Oomo
o`0JOol00`00Oomoo`1cOol0021oo`03001oogoo06]oo`8001]oo`8007=oo`0087oo00<007ooOol0
KGoo0P006goo00<007ooOol0L7oo000POol00`00Oomoo`1_Ool00`00Oomoo`0IOol2001`Ool0021o
o`80075oo`03001oogoo01Yoo`8006ioo`0087oo00<007ooOol0LGoo00<007ooOol06goo0P00K7oo
000POol00`00Oomoo`1bOol2000MOol00`00Oomoo`1YOol0021oo`03001oogoo07Aoo`03001oogoo
01]oo`03001oogoo06Qoo`0087oo00<007ooOol0MGoo00<007ooOol06goo0P00J7oo000POol2001g
Ool00`00Oomoo`0LOol00`00Oomoo`1UOol0021oo`03001oogoo07Moo`03001oogoo01aoo`03001o
ogoo06Aoo`0087oo00<007ooOol0N7oo0P007Goo00<007ooOol0Hgoo000POol00`00Oomoo`1jOol0
0`00Oomoo`0KOol00`00Oomoo`1ROol0021oo`8007aoo`03001oogoo01]oo`80069oo`0087oo00<0
07ooOol0O7oo0P007Goo00<007ooOol0Ggoo000POol00`00Oomoo`1nOol00`00Oomoo`0KOol00`00
Oomoo`1NOol000Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol3
0003Ool00`00Oomoo`1oOol00`00Oomoo`0KOol00`00Oomoo`1MOol000Ioo`03001oo`0000Moo`03
001oo`00009oo`03001oo`00009oo`03001oogoo00=oo`03001oogoo081oo`8001aoo`03001oogoo
05aoo`001Woo00<007oo00001goo00<007oo00000Woo00<007oo00000goo00<007ooOol00Woo0P00
Pgoo00<007ooOol06Woo00<007ooOol0Fgoo0006Ool00`00Ool00007Ool00`00Ool00002Ool00`00
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`23Ool00`00Oomoo`0JOol00`00Oomoo`1JOol000Io
o`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo08Ao
o`8001]oo`03001oogoo05Uoo`001goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol0QWoo00<007ooOol06Goo00<007ooOol0F7oo000POol00`00Oomo
o`27Ool00`00Oomoo`0IOol00`00Oomoo`1GOol0021oo`8008Uoo`03001oogoo01Uoo`03001oogoo
05Ioo`0087oo00<007ooOol0RGoo00<007ooOol06Goo00<007ooOol0EGoo000POol00`00Oomoo`2:
Ool00`00Oomoo`0IOol00`00Oomoo`1DOol0021oo`03001oogoo08]oo`03001oogoo01Uoo`03001o
ogoo05=oo`0087oo00<007ooOol0S7oo00<007ooOol06Goo00<007ooOol0DWoo000POol2002>Ool0
0`00Oomoo`0IOol00`00Oomoo`1AOol0021oo`03001oogoo08ioo`03001oogoo01Uoo`03001oogoo
051oo`0087oo00<007ooOol0Sgoo00<007ooOol06Goo00<007ooOol0Cgoo000POol00`00Oomoo`2@
Ool00`00Oomoo`0IOol00`00Oomoo`1>Ool0021oo`03001oogoo095oo`03001oogoo01Uoo`03001o
ogoo04eoo`0087oo0P00Tgoo00<007ooOol067oo00<007ooOol0CGoo000POol00`00Oomoo`2COol0
0`00Oomoo`0HOol00`00Oomoo`1<Ool0021oo`03001oogoo09Aoo`03001oogoo01Qoo`03001oogoo
04]oo`0087oo00<007ooOol0UGoo00<007ooOol067oo00<007ooOol0BWoo000POol00`00Oomoo`2F
Ool00`00Oomoo`0HOol00`00Oomoo`19Ool0021oo`8009Qoo`03001oogoo01Qoo`03001oogoo04Qo
o`0087oo00<007ooOol0V7oo00<007ooOol05goo00<007ooOol0B7oo000POol00`00Oomoo`2IOol0
0`00Oomoo`0GOol00`00Oomoo`17Ool000Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo
009oo`04001oogooOol20004Ool00`00Oomoo`2JOol00`00Oomoo`0GOol00`00Oomoo`16Ool000Io
o`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`05001oogooOol0002MOol00`00Oomo
o`1OOol000Ioo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000=oo`03001oogoo009oo`80
09eoo`03001oogoo05ioo`001Woo00<007oo00001goo00<007oo00000Woo00<007oo000017oo00D0
07ooOomoo`0009moo`03001oogoo05eoo`001Woo00<007oo00001goo00<007oo00000Woo00<007oo
00000Woo00<007oo00000goo00<007ooOol0WGoo00<007ooOol0GGoo0007Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`2NOol00`00Oomoo`1LOol0
021oo`800:1oo`03001oogoo05]oo`0087oo00<007ooOol0X7oo00<007ooOol0FWoo000POol00`00
Oomoo`2QOol00`00Oomoo`1IOol0021oo`03001oogoo0:5oo`03001oogoo05Uoo`0087oo00<007oo
Ool0XWoo00<007ooOol0F7oo000POol2002TOol00`00Oomoo`1GOol0021oo`03001oogoo0:Aoo`03
001oogoo05Ioo`0087oo00<007ooOol0Y7oo00<007ooOol0EWoo000POol00`00Oomoo`2UOol00`00
Oomoo`1EOol0021oo`03001oogoo0:Ioo`03001oogoo05Aoo`0087oo0P00Z7oo00<007ooOol0Dgoo
000POol00`00Oomoo`2XOol00`00Oomoo`1BOol0021oo`03001oogoo0:Uoo`03001oogoo055oo`00
87oo00<007ooOol0ZGoo00<007ooOol0DGoo000POol00`00Oomoo`2ZOol00`00Oomoo`1@Ool0021o
o`800:aoo`03001oogoo04moo`0087oo00<007ooOol0[7oo00<007ooOol0CWoo000POol00`00Oomo
o`2]Ool00`00Oomoo`1=Ool000Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo009oo`<0009oo`03001oogoo0:ioo`03001oogoo04aoo`001Woo00<007oo00001goo00<0
07oo00000Woo00<007oo000017oo00D007ooOomoo`000;1oo`03001oogoo04aoo`001Woo00<007oo
00001goo00<007oo00000Woo00<007oo00000Woo10000Woo0P00/7oo00<007ooOol0Bgoo0006Ool0
0`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`2`Ool0
0`00Oomoo`1:Ool000Ioo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000=oo`8000=oo`03
001oogoo0;5oo`03001oogoo04Uoo`001goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
0goo00D007ooOomoo`000;=oo`03001oogoo04Uoo`0087oo00<007ooOol0/Woo00<007ooOol0B7oo
000POol2002dOol00`00Oomoo`17Ool0021oo`03001oogoo0;Aoo`03001oogoo04Ioo`0087oo00<0
07ooOol0]7oo00<007ooOol0AWoo000POol00`00Oomoo`2eOol00`00Oomoo`15Ool0021oo`03001o
ogoo0;Eoo`03001oogoo04Eoo`0087oo0P00]goo00<007ooOol0A7oo000POol00`00Oomoo`2fOol0
0`00Oomoo`14Ool0021oo`03001oogoo0;Moo`03001oogoo04=oo`0087oo00<007ooOol0]goo00<0
07ooOol0@goo000POol2002iOol00`00Oomoo`12Ool0021oo`03001oogoo0;Uoo`03001oogoo045o
o`0087oo00<007ooOol0^Goo00<007ooOol0@Goo000POol00`00Oomoo`2jOol00`00Oomoo`10Ool0
021oo`03001oogoo0;]oo`03001oogoo03moo`0087oo0P00_Goo00<007ooOol0?Woo000POol00`00
Oomoo`2lOol00`00Oomoo`0nOol0021oo`03001oogoo0;eoo`03001oogoo03eoo`001goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool0_Woo00<007ooOol0?7oo0006Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool0
0`00Ool00003Ool00`00Oomoo`3mOol000Ioo`03001oo`0000Moo`03001oo`00009oo`03001oo`00
00Aoo`04001oogooOol2003nOol000Ioo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009o
o`8000Aoo`03001oogoo0?eoo`001Woo00<007oo00001goo00<007oo00000Woo00<007oo00000Woo
00<007ooOol0ogoo17oo0007Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoogoo0`00ogoo
17oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000FOol00`00
Oomoo`3oOol8Ool000moo`04001oogoo0003Ool00`00Oomoo`03Ool30002Ool20002Ool01000Ool0
07oo0P000Woo00<007ooOol0l7oo000@Ool20005Ool01@00Oomoogoo00000Woo00<007oo00000Woo
0P0000Ioo`00Ool007oo0002Ool00`00Oomoo`3`Ool0011oo`8000Uoo`06001oogoo001oo`000Woo
0P0000Ioo`00Ool007oo0002Ool00`00Oomoo`3`Ool000moo`04001oogoo0009Ool30002Ool20000
17oo000007oo1P00lgoo000NOol00`00Oomoo`3oOol001eoo`800?moo`9oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{83, 370}, {586.563, 409.625}} -> {-0.00431477, 
  0.0159125, 3.7348*^-05, 4.11788*^-05}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{},
WindowSize->{832, 824},
WindowMargins->{{0, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 32, 0, 95, "Title"],
Cell[1811, 55, 316, 7, 90, "Text"],
Cell[2130, 64, 43, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2198, 69, 123, 4, 90, "Input"],
Cell[2324, 75, 38, 1, 29, "Output"],
Cell[2365, 78, 38, 1, 29, "Output"],
Cell[2406, 81, 53, 1, 29, "Output"]
}, Open  ]],
Cell[2474, 85, 173, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[2672, 92, 417, 9, 90, "Input"],
Cell[3092, 103, 413, 11, 29, "Output"]
}, Open  ]],
Cell[3520, 117, 71, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[3616, 121, 80, 1, 30, "Input"],
Cell[3699, 124, 17446, 421, 186, 3488, 244, "GraphicsData", "PostScript", \
"Graphics"],
Cell[21148, 547, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21315, 555, 168, 3, 50, "Input"],
Cell[21486, 560, 23329, 605, 186, 7388, 404, "GraphicsData", "PostScript", \
"Graphics"],
Cell[44818, 1167, 130, 3, 29, "Output"]
}, Open  ]],
Cell[44963, 1173, 303, 7, 71, "Text"],

Cell[CellGroupData[{
Cell[45291, 1184, 246, 6, 90, "Input"],
Cell[45540, 1192, 17129, 461, 186, 4239, 297, "GraphicsData", "PostScript", \
"Graphics"],
Cell[62672, 1655, 130, 3, 29, "Output"]
}, Open  ]],
Cell[62817, 1661, 136, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[62978, 1669, 45, 1, 30, "Input"],
Cell[63026, 1672, 17796, 550, 186, 7293, 416, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[80837, 2225, 600, 9, 90, "Text"],

Cell[CellGroupData[{
Cell[81462, 2238, 302, 6, 90, "Input"],
Cell[81767, 2246, 19440, 590, 186, 7603, 440, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

