(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14281,        477]*)
(*NotebookOutlinePosition[     15250,        509]*)
(*  CellTagsIndexPosition[     15206,        505]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Physics 319
Homework #6
Oscillators\
\>", "Title",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Double click on the \[RightCeiling]",
  StyleBox["  ",
    FontWeight->"Bold"],
  "symbol with an arrow on the bottom at the far right of the subsection \
heading to open the subsection of interest.  Double clicking again will close \
it back up."
}], "Text",
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Simple Harmonic Oscillator", "Subsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Below is a definition of a simple Harmonic Oscillator.  Actually, it is a \
miniature ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program.  Note that the function has inputs for mass, spring constant k, \
amplitude and phase.  Also note the syntax for this type of definition -- \
underscores in the argument imply variable parameters; square brackets make \
this a new \"instrinsic function\" like ",
  StyleBox["Sin[]",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Exp[]",
    FontWeight->"Bold"],
  "; the \";\" symbol after the definition of \[Omega] separates lines in \
this mini-program, etc.\n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " note:  this \"cell\" is formatted as a \"text\" format as opposed to an \
\"input\" format which actually calculates things.  You can change the cell \
format by clicking on the cell brackets to the right and from the toolbar \
using ",
  StyleBox["Format -> Style",
    FontWeight->"Bold"],
  ".\n\nTo execute the cell below (to enter this mini-program into your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session) click in the cell or on the brackets to the right and press \
Shift-Enter or the Number Pad Enter by itself."
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(xsho[m_, k_, A_, \[Delta]_, t_] := 
      \((\n\t\t\[Omega]o = Sqrt[k/m]; \n\t\tA*Cos[\[Omega]o*t - \[Delta]])
        \)\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[{
  "We can now use this function like any other (e.g., ",
  StyleBox["Sin[]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Log[]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Exp[]",
    FontWeight->"Bold"],
  "...), putting in values for the different parameters.  So, first the \
program calculates \[Omega] given values for ",
  StyleBox["k",
    FontSlant->"Italic"],
  " and ",
  StyleBox["m",
    FontSlant->"Italic"],
  ", and then it finds ",
  StyleBox["xsho[t]=A*Cos[\[Omega]o*t-\[Delta]])",
    FontSlant->"Italic"],
  ", using the other parameter values.  Let ",
  StyleBox["m=1kg, k=2N/m, A=4m, \[Delta]=1rad, t=2.5s",
    FontSlant->"Italic"],
  ".  Execute the cell below to see how it works."
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(xsho[1, 2, 4, 1, 2.5]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Now let's plot the function.  Notice that ",
  StyleBox["t",
    FontSlant->"Italic"],
  " is left as a variable for ",
  StyleBox["Plot[]",
    FontWeight->"Bold"],
  " to vary."
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(xplot = Plot[xsho[1, 2, 4, 1, t], {t, 0, 7}]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[StyleBox[
"Although this is a cosine function, the peak is not centered at zero.  Find \
the expected offset given the parameters used in calculating xsho[t].  Does \
the calculated value agree with the graph? .....\n\n\t(answer here)",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "Let's find the velocity by taking the derivative of the position.  Note \
there are no underscores in the ",
  StyleBox["xsho[]",
    FontWeight->"Bold"],
  " function, because I'm not defining the function here, but using it with \
parameters ",
  StyleBox["m, k, A, \[Delta],",
    FontSlant->"Italic"],
  " and ",
  StyleBox["t",
    FontSlant->"Italic"],
  ".  This function is a little weird...if you're interested, maybe you can \
figure out a better way to do it. We need to take the derivative of ",
  StyleBox["xsho[]",
    FontWeight->"Bold"],
  " with respect to the varaible ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", but we can't differentiate with respect to a number that we're putting \
in for ",
  StyleBox["t",
    FontSlant->"Italic"],
  ".  So, I've created a new function ",
  StyleBox["dummyv",
    FontSlant->"Italic"],
  " that depends on a new variable, ",
  StyleBox["dumt",
    FontSlant->"Italic"],
  ".  We first take the derivative with respect to ",
  StyleBox["dumt",
    FontSlant->"Italic"],
  ", and then ",
  StyleBox["Evaluate[]",
    FontWeight->"Bold"],
  " it to get an expression for ",
  StyleBox["dummyv",
    FontSlant->"Italic"],
  ". Finally, we can substitute our value for ",
  StyleBox["t",
    FontSlant->"Italic"],
  " into ",
  StyleBox["dumt",
    FontSlant->"Italic"],
  " and evaluate the function....."
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(vsho[m_, k_, A_, \[Delta]_, t_] := 
      \((\n\t\tdummyv[dumt_] := 
          Evaluate[D[xsho[m, k, A, \[Delta], dumt], dumt]]; \n\t\tdummyv[t])
        \)\)], "Input",
  PageWidth->PaperWidth],

Cell["Plotting with the same values as above we have...", "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(vplot = Plot[vsho[1, 2, 4, 1, t], {t, 0, 7}]\)], "Input",
  PageWidth->PaperWidth],

Cell["\<\
To view the phase relationship more closely, let's overlay the two plots.\
\>", "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(Show[xplot, vplot]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Now, let's make a phase plot by plotting ",
  StyleBox["x[t]",
    FontSlant->"Italic"],
  " versus ",
  StyleBox["v[t]",
    FontSlant->"Italic"],
  ".  We'll use ",
  StyleBox["ParametricPlot[]",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["AspectRatio->1",
    FontWeight->"Bold"],
  " option just makes the vertical and horizontal axes the same size.  Also, \
we'll use ",
  StyleBox["PlotRange",
    FontWeight->"Bold"],
  " to use the same size axes."
}], "Text"],

Cell[BoxData[
    \(ParametricPlot[{xsho[1, 2, 4, 1, t], vsho[1, 2, 4, 1, t]}, \ {t, 0, 7}, 
      PlotRange -> {{\(-6\), 6}, {\(-6\), 6}}, \ AspectRatio -> 1, 
      AxesLabel -> {"\<x\>", \ "\<v\>"}]\)], "Input"],

Cell["\<\
Why is it an ellipse that closes on itself?.....

\t(answer here)\
\>", "Text",
  FontSlant->"Italic"]
}, Closed]],

Cell[CellGroupData[{

Cell["Damped Harmonic Oscillator", "Subsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Now, you get to follow the same routine as above but for the Damped \
Harmonic Oscillator.  I'll get you started; you fill in the rest.  I'm using \
the symbols in the ",
  StyleBox["BasicInput",
    FontSlant->"Italic"],
  " panel to your right.  If you don't have these symbols, you can use other \
variables.\n\nHere we're solving the differential equation:  ",
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot] + \(b\/m\) x\&. + \(k\/m\) x = 0\)],
    FontSlant->"Italic"],
  ".  \nLet's first double check the class notes, and solve this diffyQ using \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(DSolve[{\(\(x'\)'\)[t] + b/m*\(x'\)[t] + k/m*x[t] == 0, \(x'\)[0] == 0, 
        x[0] == A}, x[t], \ t]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[StyleBox[
"On a separate sheet of paper, show that this is indeed the same expression \
given in class for the above initial conditions.....",
  FontSlant->"Italic"]], "Text",
  PageWidth->PaperWidth],

Cell["\<\
Now, let's create the funtion.  Fill in the missing equations below following \
the general expression for the damped harmonic oscillator given in class for \
the above initial conditions.\
\>", "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(xdho[m_, k_, A_, b_, t_] := 
      \((\n\t\t\(\(\[Omega]o =. \)....\); \n\t\t\(\(\[Beta] =. \)....\); \n
        \t\t\(0.5  A\ Exp[\(-\[Beta]\)*t]...\)..\n\t\t\t\t\t)\)\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Now plot it for the following values, ",
  StyleBox["m=1kg, k=2N/m, A=4m, b=0.1",
    FontSlant->"Italic"],
  ".   Plot it with a range of ",
  StyleBox["t",
    FontSlant->"Italic"],
  " big enough to really see the function. "
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(\(dho1 =. \)....\)\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[StyleBox[
"Is this critically damped, overdamped or underdamped?  Does this make sense \
given the oscillator parameters?  If not, check your equations....\n\n\t\
(answer here)",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "Let ",
  StyleBox["b=0.5 kg/s",
    FontSlant->"Italic"],
  " and replot. Use ",
  StyleBox["PlotRange->{miny, maxy}",
    FontWeight->"Bold"],
  " to get a pretty plot.  If you have questions on syntax, type ",
  StyleBox["??Plot",
    FontWeight->"Bold"],
  " in an input cell."
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(\(dho2 =. \)....\)\)], "Input",
  PageWidth->PaperWidth],

Cell["Overlay the two plots.", "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(Show[dho1, dho2]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[{
  "You want to be able to clearly see individual oscillations, so if the two \
plots are on too big a scale or are on different scales, replot the \
individual plots on the same scale and redo the ",
  StyleBox["Show[]",
    FontWeight->"Bold"],
  " command.\n\n",
  StyleBox["Describe the differences in the two plots",
    FontSlant->"Italic"],
  ".....\n\n",
  StyleBox[" \t(answer here)\n \t",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth],

Cell[TextData[{
  StyleBox[
  "What value of b gives a critically damped solution (see notes)?  In which \
case is the drag force the biggest?",
    FontSlant->"Italic"],
  "\n\n\t",
  StyleBox["(answer here)",
    FontSlant->"Italic"],
  "\n\n\nPlot ",
  StyleBox["xdho[]",
    FontWeight->"Bold"],
  " for the critically damped case."
}], "Text",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Try the same plot with 25% less ",
  StyleBox["b",
    FontSlant->"Italic"],
  " to see the beginnings of underdamping."
}], "Text"],

Cell[TextData[{
  "Finally  we need to make a Phase Plot to compare with the no, damping \
case.  But first we need to create a velocity function.  You should be able \
to follow what was done above to create your new function.....Remember that ",
  
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " remembers variables you've already defined, so if you screw something up, \
you may need to go back and re-evaluate a previous definition (just click on \
the cell, e.g., ",
  StyleBox["xdho[]",
    FontWeight->"Bold"],
  " where the function is defined, and hit the numpad enter.)  Or, you may \
need to clear things out, e.g., ",
  StyleBox["Clear[vdho]",
    FontWeight->"Bold"],
  " \n"
}], "Text"],

Cell[TextData[{
  "Plot your result for the case of ",
  StyleBox["m=1kg, k=2N/m, A=4m, b=0.5.",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "Now make your Phase Plot for these same parameters.  Make the plot pretty, \
by adjusting the ",
  StyleBox["t",
    FontSlant->"Italic"],
  " range and the PlotRange->{{minx,maxx},{minv,maxv}}  option."
}], "Text"],

Cell[TextData[StyleBox["Why is the curve a spiral?....\n\n\t(answer here)",
  FontSlant->"Italic"]], "Text"]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "When you are ready to print the whole thing out, please do the following \
to minimize paper usage\n\[Bullet]Go back through the document and clean \
things up, like deleting unnecessary returns, trial runs, and pesky messages \
about variables being named like other variables, etc...\n\[Bullet]Then click \
on ",
  StyleBox["Format",
    FontWeight->"Bold"],
  " on the ",
  StyleBox["Toolbar",
    FontWeight->"Bold"],
  " and choose ",
  StyleBox["Printing Style Environment -> Printout",
    FontWeight->"Bold"],
  ".\n\[Bullet]Under ",
  StyleBox["File",
    FontWeight->"Bold"],
  " click ",
  StyleBox["Printing Settings -> Page Setup",
    FontWeight->"Bold"],
  " and make sure you're set for Portrait.\n\[Bullet]Now under ",
  StyleBox["File",
    FontWeight->"Bold"],
  " click ",
  StyleBox["Print",
    FontWeight->"Bold"],
  ".  In the print dialog box choose the ",
  StyleBox["Layout",
    FontWeight->"Bold"],
  " tab and select ",
  StyleBox["2 pages per sheet",
    FontSlant->"Italic"],
  ".\n\[Bullet]Click ",
  StyleBox["Print",
    FontWeight->"Bold"],
  "."
}], "Text"]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Printout",
CellGrouping->Manual,
WindowSize->{514, 547},
WindowMargins->{{Automatic, 173}, {Automatic, 20}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 85, 5, 195, "Title"],
Cell[1819, 58, 407, 11, 52, "Text"],

Cell[CellGroupData[{
Cell[2251, 73, 73, 1, 47, "Subsection"],
Cell[2327, 76, 1276, 30, 242, "Text"],
Cell[3606, 108, 179, 4, 70, "Input"],
Cell[3788, 114, 761, 25, 90, "Text"],
Cell[4552, 141, 79, 2, 30, "Input"],
Cell[4634, 145, 235, 9, 33, "Text"],
Cell[4872, 156, 102, 2, 30, "Input"],
Cell[4977, 160, 283, 4, 90, "Text"],
Cell[5263, 166, 1421, 46, 166, "Text"],
Cell[6687, 214, 214, 5, 70, "Input"],
Cell[6904, 221, 90, 1, 33, "Text"],
Cell[6997, 224, 102, 2, 30, "Input"],
Cell[7102, 228, 122, 3, 33, "Text"],
Cell[7227, 233, 76, 2, 30, "Input"],
Cell[7306, 237, 492, 18, 71, "Text"],
Cell[7801, 257, 214, 3, 70, "Input"],
Cell[8018, 262, 112, 5, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8167, 272, 73, 1, 31, "Subsection"],
Cell[8243, 275, 681, 17, 131, "Text"],
Cell[8927, 294, 161, 3, 70, "Input"],
Cell[9091, 299, 214, 4, 52, "Text"],
Cell[9308, 305, 237, 5, 52, "Text"],
Cell[9548, 312, 226, 4, 110, "Input"],
Cell[9777, 318, 284, 9, 52, "Text"],
Cell[10064, 329, 78, 2, 30, "Input"],
Cell[10145, 333, 225, 4, 90, "Text"],
Cell[10373, 339, 336, 12, 52, "Text"],
Cell[10712, 353, 78, 2, 30, "Input"],
Cell[10793, 357, 63, 1, 33, "Text"],
Cell[10859, 360, 74, 2, 30, "Input"],
Cell[10936, 364, 475, 13, 166, "Text"],
Cell[11414, 379, 373, 13, 147, "Text"],
Cell[11790, 394, 151, 5, 33, "Text"],
Cell[11944, 401, 709, 17, 147, "Text"],
Cell[12656, 420, 133, 4, 33, "Text"],
Cell[12792, 426, 234, 6, 52, "Text"],
Cell[13029, 434, 108, 1, 71, "Text"]
}, Closed]]
}, Open  ]],
Cell[13164, 439, 1113, 36, 163, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

