(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14012,        456]*)
(*NotebookOutlinePosition[     14785,        483]*)
(*  CellTagsIndexPosition[     14741,        479]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Physics 319
Homework #7
Oscillators\
\>", "Title",
  PageWidth->PaperWidth],

Cell[TextData[
"Double click on the \[RightCeiling] symbol with an arrow on the bottom at \
the far right to open the subsection of interest.  Double clicking again will \
close it back up."], "Text",
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Damped, Driven Harmonic Oscillator", "Subsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "In class, we analytically solved for the Damped, Driven, Harmonic \
Oscillator finding the ",
  StyleBox["complimentary solution",
    FontSlant->"Italic"],
  " and the ",
  StyleBox["particular solution",
    FontSlant->"Italic"],
  ", the complete solution being the sum of the two.  Let's numerically solve \
the Damped Driven Harmonic Oscillator, following the equations from our \
notes, where the driving term is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\_d\) \(cos(\(\[Omega]\_d\) t)\)\)]],
  ".  We'll write things in such a way that we can make parametric plots of ",
  
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["v",
    FontSlant->"Italic"],
  ", and \[Phi].  That way we can make ",
  StyleBox["Phase Plots",
    FontSlant->"Italic"],
  ".  The parameter values are given below.  Notice that the two of the \
normal unknown constants\nfrom the two solutions (amplitude of ",
  StyleBox["complimentary solution",
    FontSlant->"Italic"],
  " and ",
  StyleBox["phase of particular solution)",
    FontSlant->"Italic"],
  "  are contained in the inital conditions of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["v",
    FontSlant->"Italic"],
  ". "
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\[Beta] = 1; \n\[Omega]o = 10; \nAd = 1; \n\[Omega]d = 2; \n
    s1 = NDSolve[{\(x'\)[t] == v[t], 
          \(v'\)[t] == 
            \(-2\)\ \[Beta]*v[t]\  - \ \[Omega]o^2*x[t]\  + 
              Ad*Cos[\[Phi][t]], \(\[Phi]'\)[t] == \ \[Omega]d, \ 
          x[0] == \[Phi][0] == 0, v[0] == 0.3}, {x, v, \[Phi]}, {t, 0, 10}]
        \)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[StyleBox[
"On a separate sheet of paper, show that the above expressions are consistent \
with the equation derived in class....",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "Now, let's plot the ",
  StyleBox["position",
    FontSlant->"Italic"],
  " versus time."
}], "Text"],

Cell[BoxData[
    \(Plot[Evaluate[x[t] /. \ s1], {t, 0, 10}]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Why does the graph look like this?  What happens over time to the strange \
behavior at the beginning?  Give detailed descriptions of the various parts \
of the curve and the reasons for them.  (Hint:  think about the ",
  StyleBox["complimentary",
    FontSlant->"Italic"],
  " and ",
  StyleBox["particular",
    FontSlant->"Italic"],
  " solutions and the various parameter values.)   Calculate how long until \
the intial oscillatory amplitude is down to 5% of the inital amplitude.  \
Calculate the amplitude of the final motion from the solution derived in \
class.  You can answer these questions on a separate sheet of paper.\n\n\n\t"
}], "Text"],

Cell[TextData[{
  "Now, let's look at the ",
  StyleBox["phase plot",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[BoxData[
    \(ParametricPlot[Evaluate[{x[t], v[t]} /. \ s1], {t, 0, 10}, \ 
      PlotRange -> {{\(-0.04\), 0.04}, {\(-0.31\), 0.31}}]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[StyleBox[
"This curve crosses itself many times.  Why doesn't it get into a stable \
orbit the first time it crosses itself?  What is different about this system \
than the others we've looked at?\n\n\t(answer here)\n\t\t",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "It is a little confusing to follow the above curve to tell for instance \
when it crossess itself.  We can spread this out by plotting along another \
axis.  Our other variable is \n",
  StyleBox["\[Phi](t)",
    FontSlant->"Italic"],
  ".  \n\n",
  StyleBox["What does \[Phi](t) represent?\n\n\t(answer here)\n\t\n",
    FontSlant->"Italic"],
  "Let's make a 3D parametric plot....."
}], "Text"],

Cell[BoxData[
    \(p1 = 
      ParametricPlot3D[Evaluate[{\[Phi][t], x[t], v[t]} /. \ s1], {t, 0, 10}, 
        \ BoxRatios -> {4, 1, 1}, \ PlotPoints -> 400, \ 
        AxesLabel -> {\[Phi], x, v}]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Solve another example choosing parameters such that the ",
  StyleBox["complimentary solution",
    FontSlant->"Italic"],
  " does not oscillate.  Plot the ",
  StyleBox["position ",
    FontSlant->"Italic"],
  "versus time.  (Note -- the cut and paste feature may be helpful here.)"
}], "Text"],

Cell[BoxData[
    \(\(\[Beta] =. .\); \n\(\[Omega]o =. .\); \n\(Ad =. .\); \n
    \(\[Omega]d =. .\); \ns2 = NDSolve[.....]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(Plot[Evaluate[x[t] /. \ s2], {t, 0, 10}]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[StyleBox[
"Describe the curve and the reasons for it's shape....\n\n\t(answer here)\n\t\
",
  FontSlant->"Italic"]], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier Series and The DDHO", "Subsection"],

Cell[TextData[{
  "We discussed in class the possibility of letting the driving term be any \
arbitrary function.  Fourier tells us that any periodic function can be \
described by a linear sum of harmonic functions.  Since our DDHO equation of \
motion is linear, the linear sum of harmonic functions leads to a \
superposition of solutions of the form of a ",
  StyleBox["complimentary solution",
    FontSlant->"Italic"],
  " and a ",
  StyleBox["particular solution",
    FontSlant->"Italic"],
  " that we have essentially aready found.\n\nLet's drive our DDHO with a \
triangular wave: \n\n\t",
  StyleBox["F(t) = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{"{", GridBox[{
             
               {\(\(A(1\/2 + t\/\[Tau])\)\ \ \ \ \ for\ \ \  - \[Tau]\/2 < t
                   < 0\)},
             
               {\(\(A(1\/2 - t\/\[Tau])\)\ \ \ \ \ \ for\ \ \ \ \ \ \ \ 0 < t
                   < \[Tau]\/2\)}
              }]}], TraditionalForm]]],
  "\nWe can plot it below, to make sure it looks like a triangular wave.  \
Note that we've only defined it over one period, but that's all you need to \
find the Fourier Series."
}], "Text"],

Cell[BoxData[
    \(\(triangle[A_, \[Tau]_, t_] := 
      \((\nIf[t \[LessEqual] 0, f = A*\((0.5 + t/\[Tau])\), 
          f = A*\((0.5 - t/\[Tau])\)]; f)\)\t\)\)], "Input"],

Cell[BoxData[
    \(Plot[triangle[4, 1, t], {t, \(-1\), 1}]\)], "Input"],

Cell[TextData[{
  StyleBox[
  "On a separater sheet of paper find an expression for the coefficients (",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)],
    FontSlant->"Italic"],
  StyleBox[" and ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)],
    FontSlant->"Italic"],
  StyleBox[
  ") of the Fourier Series that represents this function.  Be careful with \
the limits of integration for the two parts of F(t) in each of the \
coefficient calculations  If you need a particular integral, you can find it \
here.  (e.g., Integrate[t Cos[n w t],t] )....\n",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "You should have gotten a Cosine series with coefficients equalt to ",
  Cell[BoxData[
      \(TraditionalForm\`A\/\[Pi]n\^2\)]],
  "for only odd values of ",
  StyleBox["n",
    FontSlant->"Italic"],
  ".  Let's take a look at that Fourier Series.\n\nLet ",
  StyleBox["A=\[Pi]",
    FontSlant->"Italic"],
  ", so we can just add up ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/n\^2\) \(cos(n\[Omega]t)\)\)]],
  "for odd ",
  StyleBox["n",
    FontSlant->"Italic"],
  ".  Let's just plot the first two terms first with \[Omega]=\[Pi]."
}], "Text"],

Cell[BoxData[
    \(\[Omega] = \[Pi]; \nPlot[....., {t, \(-1\), 1}]\)], "Input"],

Cell["Plot the next two terms.", "Text"],

Cell[BoxData[
    \(\[Omega] = \[Pi]; \nPlot[.......\ \(, {t, \(-1\), 1}\)]\)], "Input"],

Cell[TextData[{
  "We can get even fancier by using the ",
  StyleBox["Sum[]",
    FontWeight->"Bold"],
  " function.  Take a look at the syntax and use ",
  StyleBox["Sum[] ",
    FontWeight->"Bold"],
  "plot the first 100 terms."
}], "Text"],

Cell[BoxData[
    \(?? Sum\)], "Input"],

Cell[TextData[{
  "Note that you only want odd terms, so you will have to get the indexing of \
the ",
  StyleBox["Sum[]",
    FontWeight->"Bold"],
  " function correct.  Also, go ahead and plot over a wider range (say \
t=-4,4s); this Fourier Series will repeat itself."
}], "Text"],

Cell[BoxData[
    \(\[Omega] = \[Pi]; \nPlot[.....]\)], "Input"],

Cell[TextData[{
  "Before we put this into our Damped Driven Harmonic  Oscillator, let's put \
in a simpler expression.  Using the DDHO routine at the beginning of this \
notebook, put in a driving function of ",
  StyleBox["Ad (Cos[",
    FontSlant->"Italic"],
  "\[Phi][t]]+3 ",
  StyleBox["Cos[3 ",
    FontSlant->"Italic"],
  "\[Phi][t]])."
}], "Text"],

Cell[BoxData[
    \(\[Beta] = 1; \n\[Omega]o = 10; \nAd = 1; \n\[Omega]d = 2; \n
    s3 = NDSolve[....., {t, 0, 10}]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Plot ",
  StyleBox["x[t]",
    FontSlant->"Italic"],
  " vs. ",
  StyleBox["t.",
    FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
    \(\(Plot[.....], {t, 0, 10}]\)\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[StyleBox[
"How does the amplitude here compare with the case at the beginning of the \
notebook?\n\n\t(answer here)\n\t",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
Can you pick a driving frequency that will make the amplitude even bigger?  \
Try it.\
\>", "Text"],

Cell[BoxData[
    \(\[Beta] = 1; \n\[Omega]o = 10; \nAd = 1; \n\(\(\[Omega]d =. \)....\); \n
    s4 = NDSolve[.....]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(Plot[Evaluate[x[t] /. \ s4], {t, 0, 10}]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[StyleBox[
"Is this a bigger amplitude?  Why or why not?\n\n\t(answer here)\n\t\nThis \
looks almost sinusoidal.  Why - despite the complexity of the driving \
function?\t\n\n\t(answer here)",
  FontSlant->"Italic"]], "Text"],

Cell["Now, let's put in the triangular wave.  ", "Text"],

Cell[BoxData[
    \(\(.....\)\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Plot ",
  StyleBox["x[t]",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "And just for fun, let's look at the 3D parametric plot (I'm assuming \
you've called your last calculation ",
  StyleBox["s5",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(p2 = 
      ParametricPlot3D[Evaluate[{\[Phi][t], x[t], v[t]} /. \ s5], {t, 0, 10}, 
        \ BoxRatios -> {4, 1, 1}, \ PlotPoints -> 400, \ 
        AxesLabel -> {\[Phi], x, v}]\)], "Input",
  PageWidth->PaperWidth],

Cell[TextData[StyleBox[
"Why is the final motion not sinusoidal?\n\n\t(answer here)",
  FontSlant->"Italic"]], "Text"]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "When you are ready to print the whole thing out, please do the following \
to minimize paper usage\n\[Bullet]Go back through the document and clean \
things up, like deleting unnecessary returns, trial runs, and pesky messages \
about variables being named like other variables, etc...\n\[Bullet]Then click \
on ",
  StyleBox["Format",
    FontWeight->"Bold"],
  " on the ",
  StyleBox["Toolbar",
    FontWeight->"Bold"],
  " and choose ",
  StyleBox["Printing Style Environment -> Printout",
    FontWeight->"Bold"],
  ".\n\[Bullet]Under ",
  StyleBox["File",
    FontWeight->"Bold"],
  " click ",
  StyleBox["Printing Settings -> Page Setup",
    FontWeight->"Bold"],
  " and make sure you're set for Portrait.\n\[Bullet]Now under ",
  StyleBox["File",
    FontWeight->"Bold"],
  " click ",
  StyleBox["Print",
    FontWeight->"Bold"],
  ".  In the print dialog box choose the ",
  StyleBox["Layout",
    FontWeight->"Bold"],
  " tab and select ",
  StyleBox["2 pages per sheet",
    FontSlant->"Italic"],
  ".\n\[Bullet]Click ",
  StyleBox["Print",
    FontWeight->"Bold"],
  "."
}], "Text"]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
PrintingStyleEnvironment->"Printout",
CellGrouping->Manual,
WindowSize->{446, 481},
WindowMargins->{{11, Automatic}, {Automatic, 11}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 85, 5, 195, "Title"],
Cell[1819, 58, 329, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[2173, 69, 81, 1, 47, "Subsection"],
Cell[2257, 72, 1272, 38, 166, "Text"],
Cell[3532, 112, 393, 8, 170, "Input"],
Cell[3928, 122, 177, 3, 52, "Text"],
Cell[4108, 127, 120, 5, 33, "Text"],
Cell[4231, 134, 98, 2, 30, "Input"],
Cell[4332, 138, 673, 13, 204, "Text"],
Cell[5008, 153, 115, 5, 33, "Text"],
Cell[5126, 160, 178, 3, 50, "Input"],
Cell[5307, 165, 270, 4, 128, "Text"],
Cell[5580, 171, 415, 10, 204, "Text"],
Cell[5998, 183, 237, 5, 70, "Input"],
Cell[6238, 190, 314, 8, 71, "Text"],
Cell[6555, 200, 161, 3, 110, "Input"],
Cell[6719, 205, 98, 2, 30, "Input"],
Cell[6820, 209, 138, 3, 90, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6995, 217, 49, 0, 31, "Subsection"],
Cell[7047, 219, 1185, 28, 10132, "Text"],
Cell[8235, 249, 173, 3, 50, "Input"],
Cell[8411, 254, 72, 1, 30, "Input"],
Cell[8486, 257, 652, 18, 109, "Text"],
Cell[9141, 277, 570, 17, 115, "Text"],
Cell[9714, 296, 80, 1, 50, "Input"],
Cell[9797, 299, 40, 0, 33, "Text"],
Cell[9840, 301, 88, 1, 50, "Input"],
Cell[9931, 304, 243, 8, 52, "Text"],
Cell[10177, 314, 39, 1, 30, "Input"],
Cell[10219, 317, 283, 7, 71, "Text"],
Cell[10505, 326, 64, 1, 50, "Input"],
Cell[10572, 329, 356, 10, 71, "Text"],
Cell[10931, 341, 154, 3, 110, "Input"],
Cell[11088, 346, 136, 7, 33, "Text"],
Cell[11227, 355, 86, 2, 30, "Input"],
Cell[11316, 359, 168, 3, 109, "Text"],
Cell[11487, 364, 109, 3, 33, "Text"],
Cell[11599, 369, 154, 3, 110, "Input"],
Cell[11756, 374, 98, 2, 30, "Input"],
Cell[11857, 378, 238, 4, 147, "Text"],
Cell[12098, 384, 56, 0, 33, "Text"],
Cell[12157, 386, 67, 2, 30, "Input"],
Cell[12227, 390, 89, 5, 33, "Text"],
Cell[12319, 397, 188, 6, 52, "Text"],
Cell[12510, 405, 237, 5, 70, "Input"],
Cell[12750, 412, 118, 2, 71, "Text"]
}, Closed]]
}, Open  ]],
Cell[12895, 418, 1113, 36, 220, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

