(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16653,        495]*)
(*NotebookOutlinePosition[     17388,        521]*)
(*  CellTagsIndexPosition[     17344,        517]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Physics 319
Homework #8
Non-Linear\
\>", "Title",
  PageWidth->PaperWidth],

Cell[TextData[
"Double click on the \[RightCeiling] symbol with an arrow on the bottom at \
the far right to open the subsection of interest.  Double clicking again will \
close it back up."], "Text",
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Simple Pendulum", "Subsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "We have analyzed the motion of a simple pendulum several times now, but \
why let that stop us from looking at the system yet again, and again....So \
far we have used the small angle approximation leading to Sin[\[Theta]]\
\[TildeTilde]\[Theta], but we now want to keep the Sin[\[Theta]] in place.\n\n\
On a separate sheet of paper show that the potential is given by ",
  StyleBox["U(\[Theta])=mgl(1-Cos[\[Theta]])",
    FontSlant->"Italic"],
  ".\nNow use the gradient ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(\[Del]\&\[RightVector]\), 
              StyleBox["U",
                FontSlant->"Italic"]}], "=", 
            \(\(\[PartialD]U\/\[PartialD]r\) e\&^\_r + 
              \(1\/r\) \(\[PartialD]U\/\[PartialD]\[Theta]\) 
                e\&^\_\[Theta]\)}], ")"}], TraditionalForm]]],
  " to find the force ",
  StyleBox["F(\[Theta])",
    FontSlant->"Italic"],
  ".\nWith this expression for the force, use the small angle approximation \
to find the approximated potential (This should be analogous to the case for \
a spring).\n\nNow you're ready  to plot the two expressions for the potential \
to see how they compare."
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(potential[m_, g_, l_, \[Theta]_] := \ 
      m\ g\ l \((1 - Cos[\[Theta]])\)\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(p1 = 
      Plot[potential[1, 9.8, 0.1, \[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}]
        \)], "Input"],

Cell[BoxData[
    \(p2 = 
      Plot[0.5*1 \((9.8)\) 0.1*\[Theta]^2, {\[Theta], \(-\[Pi]\), \[Pi]}]\)], 
  "Input"],

Cell[BoxData[
    \(Show[p1, p2]\)], "Input"],

Cell[TextData[{
  "The Sin[\[Theta]] causes a non-linearity in the potential.  That is, a \
non-parabolic potential implies a non-linear restoring force.  This also \
means there is a non-linearity in the equation of motion, \n",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Theta](t)\)\&\[DoubleDot] + \(\[Omega]\_o\%2\) sin[\[Theta](t)] = 
        0\)]],
  ".This equation is in general not analytically solvable without \
approximatons, although the period can be found with the use of elliptic \
integrals (See Marion and Thornton, Sec. 4.4).  We will look at the angular \
position versus time, using numerical techniques.\n\nLet's continue to \
compare the approximate solution to the real solution.  So let's find ",
  StyleBox["\[Theta](t).",
    FontSlant->"Italic"],
  "   We'll use the following initial conditions ",
  StyleBox["\[Theta](0)=",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`45\^o\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta](0)\)\&. = 0\)]],
  " with an angular frequency of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \@\(g\/l\)\)]],
  ", using the above values for ",
  StyleBox["g",
    FontSlant->"Italic"],
  " and ",
  StyleBox["l",
    FontSlant->"Italic"],
  ".  From your notes you can write down the solution for the approximate \
case as just the SHO (",
  StyleBox["\[Theta](t)=A Cos[\[Omega] t - \[Delta]])",
    FontSlant->"Italic"],
  ".  Find the coefficients given the initial conditions and plot the \
function for several periods."
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(\(p3 =. \)....\)\)], "Input"],

Cell[TextData[{
  "For the exact solution, let's use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s numerical solver, ",
  StyleBox["NDSolve[]",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(g = 9.8; \nl = 0.1; \n
    s1 = NDSolve[{\(\[Theta]'\)[t] == \[Omega][t], \ 
          \(\[Omega]'\)[t] + \((g/l)\) Sin[\[Theta][t]] == 0, 
          \[Theta][0] == \[Pi]/2, \[Omega][0] == 0}, {\[Theta], \[Omega]}, {
          t, 0, 6}]\)], "Input"],

Cell[BoxData[
    \(p4 = Plot[Evaluate[\[Theta][t] /. s1], {t, 0, 2}]\)], "Input"],

Cell[BoxData[
    \(Show[p3, p4]\)], "Input"],

Cell[TextData[StyleBox[
"How do the two graphs compare?  What can you say about the approximate \
solution?  Use the above procedure to make plots for different values of the \
inital angle, \[Theta][0]=?, to estimate at what initial angle the \
approximation holds. \n\n\t(answer here)\n\t\n\tDo your work making new \
graphs below by clicking in-between this cell and the next to start and new \
input cell....\n",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "So...for about what initial angle does the approximation look reasonable?  \
For how many periods?\n\n\n\t",
  StyleBox["(answer here)",
    FontSlant->"Italic"]
}], "Text",
  FontSlant->"Italic"],

Cell[TextData[StyleBox[
"\nWhat happens to the exact waveform as time goes on?  What does this imply \
about the exact period?  Is this consistent with the trend of Eq. 4.29 in \
Marion and Thronton?\n\n\t(answer here)",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "We can track the separation of these two plots by taking the ratio of the \
values of the functions at some distant period.  Let's look at the 10th \
period and see how different the solutions are as a function of inital angle. \
 I've written this like a little program.  Initial parameter values are given \
up front, as well as initializing three number ",
  StyleBox["Lists",
    FontSlant->"Italic"],
  " (arrays for you programers).  The ",
  StyleBox["Table[]",
    FontWeight->"Bold"],
  " function will make what ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " calls a ",
  StyleBox["List",
    FontSlant->"Italic"],
  ".  I've used the Table commad here to just fill our three lists with \
zeros.  In the Do Loop we iterate through the calculations, each time through \
making the intial angle, ",
  Cell[BoxData[
      \(\[Theta]\_o\)]],
  ", a little bigger.  In the loop we access each new element in the ",
  StyleBox["List",
    FontSlant->"Italic"],
  " (array) and put the new calculation in the new position in the list."
}], "Text"],

Cell[BoxData[
    \(\(g = 9.8; \nl = 0.1; \n\[Tau] = 2*Pi/Sqrt[g/l]; \n
    exact = Table[0, {100}]; \napprox = Table[0, {100}]; \n
    ratio = Table[0, {100}]; \n\[Theta]\_o = 0.0001; \n
    Do[\n\t\t\t\t\[Theta]\_o = \[Theta]\_o + 0.01; \n\t\t\t\t
      s4\  = NDSolve[{\(\[Theta]'\)[t] == \[Omega][t], \ 
            \(\[Omega]'\)[t] + \((g/l)\) Sin[\[Theta][t]] == 0, 
            \[Theta][0] == \[Theta]\_o, \[Omega][0] == 0}, {\[Theta], 
            \[Omega]}, {t, 10*\[Tau]}]; \n\t\t\t\t
      exact[\([i]\)] = Evaluate[\[Theta][10*\[Tau]] /. s4]; \n\t\t\t\t
      approx[\([i]\)] = \[Theta]\_o*Cos[Sqrt[9.8/0.1]\ *10*\[Tau]]; \n\t\t\t\t
      ratio[\([i]\)] = exact[\([i]\)]/approx[\([i]\)]\n\t\t, {i, 1, 100}]\n
    \)\)], "Input"],

Cell["\<\
If you want to take a look a the lists of numbers, just type the name of the \
list without any brackets in a new cell and execute it.\
\>", "Text"],

Cell[TextData[{
  "Now we can plot the diff function.  Note that I use ",
  StyleBox["ListPlot[]",
    FontWeight->"Bold"],
  " since diff is a list of numbers.  The ",
  StyleBox["Table[]",
    FontWeight->"Bold"],
  " function often puts in extra {}'s so ",
  StyleBox["Flatten[]",
    FontWeight->"Bold"],
  " is used to take them out.  Anyway, here it is!"
}], "Text"],

Cell[BoxData[
    \(ListPlot[Flatten[ratio]]\)], "Input"],

Cell[TextData[{
  "Why does the curve start to turn around (It might help to look at a ",
  Cell[BoxData[
      \(ListPlot[]\)], "Input"],
  StyleBox[" of exact and approx -- Don't forget to Flatten[])",
    FontWeight->"Bold"],
  "?\n\n\t",
  StyleBox["(answer here)",
    FontSlant->"Italic"],
  "\n\nWhat is the approximate value of the initial angle when the exact and \
approximate solutions differ by about 10%? (You'll have to conver the \
horizontal axis from what is currently the number in the list of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_o\)]],
  " values to actual ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_o\)]],
  " values.)\n\n\t",
  StyleBox["(answer here)",
    FontSlant->"Italic"]
}], "Text",
  FontSlant->"Italic"],

Cell["\<\
To  finish up with the simple pendulum, let's make a phase plot.  We expect \
to see a nice oscillator.....\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot[Evaluate[{\[Theta][t], \[Omega][t]} /. \ s1], {t, 0, 6}]
      \)], "Input"],

Cell[TextData[StyleBox[
"A final question.  If you were armed only with the approximate solution, \
would you feel confident predicting the position of the pendulum at long \
times?  Why?  For what initial angles?\n\n\t(answer here)",
  FontSlant->"Italic"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fun with numbers!", "Subsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "When you watched the movie \"Chaos, Fractals and Dynamics: Conputer \
Experiments in Mathematics\", with Robert Devaney, you saw how the process of \
iteration can lead to some strange results.  In this section of the notebook, \
we'll perform so of the calculations he showed us.\n\nFirst, take your \
calculator and on a separate piece of paper, successively take the square \
root of a number.  ",
  StyleBox[
  "Do you see the values converge to a single value?\n\n\t(answer here)",
    FontSlant->"Italic"],
  "\n\nNow let's let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " do the iterations for us.  Below we have a function that will iterate the \
",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Placeholder]\)]],
  " function.  Again, we're using the Table function to create a list into \
which we will place the values found at each iteration.  The input to the \
function is the initial value and the number of iterations."
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(sroot[xo_, N_] := 
      \((\n\t\tslist = Table[0, {N}]; \n\t\tx = xo; \n\t
        Do[{x = Sqrt[x]; \ slist[\([i]\)] = x}, {i, 1, N}]\n\t)\)\)], "Input"],

Cell["Find the first 10 iterations for some starting value.", "Text"],

Cell[BoxData[
    \(sroot[3, 10]\)], "Input"],

Cell["Now to look at the result, we just execute the list, slist.", "Text"],

Cell[BoxData[
    \(slist\)], "Input"],

Cell[TextData[{
  "We can of course plot this using ",
  StyleBox["ListPlot[]",
    FontWeight->"Bold"],
  ".  Note that I've increased the size of the points to make it more \
readable."
}], "Text"],

Cell[BoxData[
    \(sroot[16, 20]; \n
    ListPlot[Abs[slist], Prolog -> AbsolutePointSize[5], PlotRange -> {0, 5}]
      \)], "Input"],

Cell[TextData[{
  "Plat with this function.  ",
  StyleBox["Does this ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\@\[Placeholder]\)]],
  " ",
  StyleBox[
  "function always converge?  To what value?\n\n\t(answer here)\n\t",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "Now let's look at the Sine function",
  StyleBox[" (c*sin[x])",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(sine[xo_, c_, N_] := 
      \((\n\t\tylist = Table[0, {N}]; \n\t\tx = xo; \n\t
        Do[{x = c*Sin[x]; \ ylist[\([i]\)] = x}, {i, 1, N}]\n\t)\)\)], "Input"],

Cell[TextData[{
  "Choose an intial x-value and play with the plots for c ranging from 0.5-3, \
stepping by 0.2.  You ",
  StyleBox["DO NOT",
    FontWeight->"Bold"],
  " need to keep all of these graphs!!  Just keep changing the c-value in the \
same graph setup below and then describe what you see."
}], "Text"],

Cell[BoxData[
    \(sine[1, 2.8, 30]; \nListPlot[ylist, Prolog -> AbsolutePointSize[5]]\)], 
  "Input"],

Cell[TextData[StyleBox[
"What seems to be happening?\n\n\t(answer here)\n\nPlay  with it some more \
right around 2.50-2.75.  What is happening to the number of solutions that \
are possible?  As you increase the number of iterations by 1, 2, 3 (i.e., as \
a function of the horizontal axis) what happens to the solution?\n\n\t(answer \
here)",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "Finally, let's look at the quadratic case ",
  StyleBox["(c*x*(1-x)).",
    FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
    \(quadratic[xo_, c_, N_] := 
      \((\n\t\txlist = Table[0, {N}]; \n\t\tx = xo; \n\t
        Do[{x = c*x*\((1 - x)\); \ xlist[\([i]\)] = x}, {i, 1, N}]\n\t)\)\)], 
  "Input"],

Cell["\<\
Again, play with the plot, choosing a starting value and then leaving that \
fixed.  Adjust the c-value from 0.5 to 4.0.  Again, just keep using the same \
setup below -- there's no need to have a thousand graphs here.\
\>", "Text"],

Cell[BoxData[
    \(quadratic[0.3, 3.45, 100]; \n
    ListPlot[xlist, Prolog -> AbsolutePointSize[4]]\)], "Input"],

Cell[TextData[{
  "How many solutions are there for c=1, c=2, c=3, c=4?\n\n\t",
  StyleBox["(answer here)",
    FontSlant->"Italic"],
  "\n\t\nGo back and play some more in the c=3-4 range.  Where does this \
function make the transistion from 2 to four solutions? eight solutions?\n\n\t\
",
  StyleBox["(answer here)",
    FontSlant->"Italic"],
  "\n\nFor c<2, do you think you could predict the result after many \
iterations (think long time for a physical system)?  What about c=3?  What \
about c=3.5?  What about c>4? \n\n\t",
  StyleBox["(answer here)",
    FontSlant->"Italic"],
  "\n\nWhat word would you use to describe the nature of the solutions for \
c>4?\n\n\t",
  StyleBox["(answer here)",
    FontSlant->"Italic"]
}], "Text",
  FontSlant->"Italic"],

Cell[TextData[{
  "When you are ready to print the whole thing out, please do the following \
to minimize paper usage\n\[Bullet]Go back through the document and clean \
things up, like deleting unnecessary returns, trial runs, and pesky messages \
about variables being named like other variables, etc...\n\[Bullet]Then click \
on ",
  StyleBox["Format",
    FontWeight->"Bold"],
  " on the ",
  StyleBox["Toolbar",
    FontWeight->"Bold"],
  " and choose ",
  StyleBox["Printing Style Environment -> Printout",
    FontWeight->"Bold"],
  ".\n\[Bullet]Under ",
  StyleBox["File",
    FontWeight->"Bold"],
  " click ",
  StyleBox["Printing Settings -> Page Setup",
    FontWeight->"Bold"],
  " and make sure you're set for Portrait.\n\[Bullet]Now under ",
  StyleBox["File",
    FontWeight->"Bold"],
  " click ",
  StyleBox["Print",
    FontWeight->"Bold"],
  ".  In the print dialog box choose the ",
  StyleBox["Layout",
    FontWeight->"Bold"],
  " tab and select ",
  StyleBox["2 pages per sheet",
    FontSlant->"Italic"],
  ".\n\[Bullet]Click ",
  StyleBox["Print",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
PrintingStyleEnvironment->"Printout",
WindowSize->{566, 624},
WindowMargins->{{23, Automatic}, {-4, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, 2}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 84, 5, 195, "Title"],
Cell[1818, 58, 329, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[2172, 69, 62, 1, 47, "Subsection"],
Cell[2237, 72, 1246, 27, 207, "Text"],
Cell[3486, 101, 134, 3, 30, "Input"],
Cell[3623, 106, 123, 3, 30, "Input"],
Cell[3749, 111, 115, 3, 30, "Input"],
Cell[3867, 116, 45, 1, 30, "Input"],
Cell[3915, 119, 1576, 39, 276, "Text"],
Cell[5494, 160, 51, 1, 30, "Input"],
Cell[5548, 163, 201, 8, 33, "Text"],
Cell[5752, 173, 269, 5, 110, "Input"],
Cell[6024, 180, 82, 1, 30, "Input"],
Cell[6109, 183, 45, 1, 30, "Input"],
Cell[6157, 186, 449, 7, 185, "Text"],
Cell[6609, 195, 215, 6, 90, "Text"],
Cell[6827, 203, 253, 4, 109, "Text"],
Cell[7083, 209, 1081, 26, 166, "Text"],
Cell[8167, 237, 740, 12, 330, "Input"],
Cell[8910, 251, 158, 3, 52, "Text"],
Cell[9071, 256, 372, 11, 52, "Text"],
Cell[9446, 269, 57, 1, 30, "Input"],
Cell[9506, 272, 763, 21, 204, "Text"],
Cell[10272, 295, 131, 3, 33, "Text"],
Cell[10406, 300, 111, 2, 30, "Input"],
Cell[10520, 304, 267, 4, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10824, 313, 64, 1, 47, "Subsection"],
Cell[10891, 316, 1004, 21, 280, "Text"],
Cell[11898, 339, 174, 3, 110, "Input"],
Cell[12075, 344, 69, 0, 33, "Text"],
Cell[12147, 346, 45, 1, 30, "Input"],
Cell[12195, 349, 75, 0, 33, "Text"],
Cell[12273, 351, 38, 1, 30, "Input"],
Cell[12314, 354, 199, 6, 52, "Text"],
Cell[12516, 362, 135, 3, 70, "Input"],
Cell[12654, 367, 287, 10, 90, "Text"],
Cell[12944, 379, 126, 5, 33, "Text"],
Cell[13073, 386, 178, 3, 110, "Input"],
Cell[13254, 391, 314, 7, 71, "Text"],
Cell[13571, 400, 103, 2, 50, "Input"],
Cell[13677, 404, 377, 6, 185, "Text"],
Cell[14057, 412, 127, 4, 33, "Text"],
Cell[14187, 418, 193, 4, 110, "Input"],
Cell[14383, 424, 242, 4, 52, "Text"],
Cell[14628, 430, 114, 2, 50, "Input"],
Cell[14745, 434, 764, 19, 337, "Text"],
Cell[15512, 455, 1113, 36, 147, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

