(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12764,        409]*)
(*NotebookOutlinePosition[     13509,        434]*)
(*  CellTagsIndexPosition[     13465,        430]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Physics 319
Homework #9
Non-Linear Dynamics II\
\>", "Title",
  PageWidth->PaperWidth],

Cell[TextData[
"Double click on the \[RightCeiling] symbol with an arrow on the bottom at \
the far right to open the subsection of interest.  Double clicking again will \
close it back up."], "Text",
  PageWidth->PaperWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Modified van der Pol Equation", "Subsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "We discussed in class a version of the van der Pol equation.  Here we will \
look at it in a bit more detail.\nThe equation is:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot] - \(\[Mu](
              x\_o\%2 - x\^2 - x\& . \^2\/\[Beta]\^2)\) 
            x\& .  + \(\[Omega]\_o\%2\) x = 0\)]],
  "\nRewriting as two first-order differential equations, we have\n\t",
  Cell[BoxData[{
      \(TraditionalForm\`x\& .  = v\), "\[IndentingNewLine]", 
      \(TraditionalForm\`v\& .  - \(\[Mu](
              x\_o\%2 - x\^2 - v\^2\/\[Beta]\^2)\) v + \(\[Omega]\_o\%2\) x = 
        0\)}]],
  "\n",
  "On a separate sheet of paper show that if we let ",
  StyleBox["\[Mu]=1, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_o = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = 1\)]],
  ", \[Beta]=1, the following is a solution for ",
  StyleBox["x: x(t)=cos(t)",
    FontSlant->"Italic"],
  ".",
  "  Do this by just plugging in for ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["v",
    FontSlant->"Italic"],
  " and verifying that the equation goes to 0.",
  "\n",
  "\n\nLet's numerically solve this so we can make some plots.  Let ",
  StyleBox["\[Mu]=1, ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_o = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = 1\)]],
  ", \[Beta]=1.  We want to plot this for different starting values of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " (",
  StyleBox["xinit",
    FontSlant->"Italic"],
  "), so I've included a parameter xinit in the input.  "
}], "Text",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(vanderpol[\[Mu]_, xo_, \[Omega]o_, \[Beta]_, 
        xinit_] := \((\[IndentingNewLine]s1 = 
          NDSolve[{\(x'\)[t] \[Equal] 
                v[t], \ \(v'\)[
                  t] \[Equal] \[Mu] \((xo^2 - x[t]^2 - v[t]^2/\[Beta]^2)\) 
                    v[t] - \[Omega]o^2*x[t], x[0] \[Equal] xinit, 
              v[0] \[Equal] 0}, {x, v}, {t, 0, 80}, 
            MaxSteps \[Rule] 4000]\[IndentingNewLine])\)\)], "Input"],

Cell[TextData[{
  "Plot ",
  StyleBox["x[t]",
    FontSlant->"Italic"],
  " ",
  " for a few different values of the starting position, ",
  StyleBox["xinit",
    FontSlant->"Italic"],
  ", -- some with ",
  StyleBox["xinit<",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " -- some with ",
  StyleBox["xinit>",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(vanderpol[1, 1, 1, 1, 0.1];\)\), "\[IndentingNewLine]", 
    \(Plot[Evaluate[x[t] /. s1], {t, 0, 80}]\)}], "Input"],

Cell[TextData[{
  "What is happening to the amplitude as time goes on if ",
  StyleBox["xinit<",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  "?\n\n\t(answer here)\n\nWhat happens if ",
  StyleBox["xinit>",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  "?\n\n\t(answer here)\n\t\nWhat do you expect the phase plot to look like \
for these to cases?\t\n\t\n\t(answer here)"
}], "Text",
  FontSlant->"Italic"],

Cell[TextData[{
  "Now make a Phase Plot for a couple cases.  Play around with different \
values of \[Mu] and ",
  StyleBox["xinit",
    FontSlant->"Italic"],
  ".  Try and get the convergence to happen slowly, so you see lots of \
spirals and a clear convergence to a circle.  B",
  "ecause the motion is attracted to this region of phase space, and \
eventually occupies only this region of phase space, t",
  "his circle is the ",
  StyleBox["attractor",
    FontWeight->"Bold"],
  " for this equation. ",
  " Show plots for ",
  StyleBox["xinit<",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " and ",
  StyleBox["xinit>",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]]
}], "Text"],

Cell[BoxData[{
    \(\(vanderpol[0.1, 1, 1, 1, 0.5];\)\), "\[IndentingNewLine]", 
    \(ParametricPlot[Evaluate[{x[t], v[t]} /. s1], {t, 0, 80}, \ 
      AspectRatio \[Rule] 1]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Bifurcation", "Subsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "In this section we will look at bifurcation, or the period doubling route \
to chaos.  We will use the \"logistic\" equation which is the \"quadratic\" \
function from HW8.  Let's look at that again briefly before looking at \
bifurcation.\n\nHere is the function from HW8 ",
  StyleBox["[x=c(1-x)x]",
    FontSlant->"Italic"],
  ".  Since we use this equation iteratively, it might be better to write it \
as\n\t",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + 1\) = \(c(1 - x\_n)\) x\_n\)]],
  ".\nThat is, each next value of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " depends on the previous.  This is the feedback nature of the non-linear \
equations we've been studying.\n\nWe saw last time that the value of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " after many iterations (large ",
  StyleBox["n",
    FontSlant->"Italic"],
  ") may or may not converge to a given number depending on the value of ",
  StyleBox["c",
    FontSlant->"Italic"],
  "! "
}], "Text",
  PageWidth->PaperWidth],

Cell[TextData[{
  "Play with this function again for a couple minutes putting in different \
values of ",
  StyleBox["c",
    FontSlant->"Italic"],
  ", especially around ",
  StyleBox["c<2, c=3, c=3.5, c>4",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(quadratic[xo_, c_, 
        N_] := \((\n\t\txlist = Table[0, {N}]; \n\t\tx = xo; \n\t
        Do[{x = c*x*\((1 - x)\); \ xlist[\([i]\)] = x}, {i, 1, 
            N}]\n\t)\)\)], "Input"],

Cell[BoxData[{
    \(\(quadratic[0.3, 3.56, 100];\)\), "\n", 
    \(ListPlot[xlist, Prolog -> AbsolutePointSize[3]]\)}], "Input"],

Cell[TextData[{
  StyleBox["For large n-values, what happens to the number of solutions as \
the c-value is increased?  \n\n\t",
    FontSlant->"Italic"],
  "(answer here)",
  StyleBox["\n\nCompare the results of c=3.52 and c=3.56.  What happend to \
the number of solutions?\n\n\t",
    FontSlant->"Italic"],
  "(answer here)",
  StyleBox["\n\t\n",
    FontSlant->"Italic"],
  "It would be interesting to plot ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "at a big value of n, and see how this varies versus c.  This is called a \
",
  StyleBox["bifurcation diagram",
    FontWeight->"Bold"],
  ".  To do this we need to redine our function so that we don't create a \
table of values, but only the last one for a given value of n.  Check it \
out."
}], "Text"],

Cell[BoxData[
    \(quadone[xo_, c_, N_] := \((\n\t\tx = xo; \n\t
        Do[x = c*x*\((1 - x)\), {N}]; x\n\t)\)\)], "Input"],

Cell["Put in some values and see what the result is. ", "Text"],

Cell[TextData[{
  "So, you just get the value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  ", not a list of all the values leading up to it.  Let's now plot ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "for lots of different ",
  StyleBox["c-values.",
    FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
    \(ListPlot[Table[quadone[ .3, c, 400], {c, 1, 4,  .003}], 
      Prolog -> AbsolutePointSize[1]]\)], "Input"],

Cell[TextData[{
  "Pretty cool, but there are jumps in the solution.  It looks like we're \
missing something. ",
  StyleBox[" \n\nWhat's going on?  (It may be helpful to look back at our \
original quadratic[] function. Plot quadratic[] again for c=3.52 and describe \
how the solution varies in the graph as you look at increasing n-values.)\n\n\
\t",
    FontSlant->"Italic"],
  "(answer here)",
  StyleBox["\n",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "So, to make a complete bifurcation diagram, we need to overlay a bunch of \
plots, each with ",
  StyleBox["n=n+1,",
    FontSlant->"Italic"],
  " compared to the previous.  Let's zoom in a little (shorten the range of \
",
  StyleBox["c",
    FontSlant->"Italic"],
  ") and get started making the plots.  Notice that the horizontal axis is \
not plotting ",
  StyleBox["c-values",
    FontSlant->"Italic"],
  " but just the number in the list.\n"
}], "Text"],

Cell[BoxData[
    \(p1 = 
      ListPlot[Table[quadone[ .3, c, 400], {c, 2.8, 4,  .003}], 
        Prolog -> AbsolutePointSize[1]]\)], "Input"],

Cell[BoxData[
    \(p2 = 
      ListPlot[Table[quadone[ .3, c, 401], {c, 2.8, 4,  .003}], 
        Prolog -> AbsolutePointSize[1]]\)], "Input"],

Cell[TextData[{
  StyleBox["How and why are the graphs different?\n\n\t",
    FontSlant->"Italic"],
  "(answer here)",
  "\n\nContinue this process, making plots of the next ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  ".....Use the Show[] command to overlay the plots (I think four to eight \
plots is enough to see what's going on -- remember to name them, e.g., p1, \
p2, p3, p4 so you can use Show[p1,p2,p3,p4] to overlay them.)  Your result \
should look like Fig 4-22 of the text. \n\nTo see more detail, just keep \
increasing ",
  StyleBox["N ",
    FontSlant->"Italic"],
  " by 1 and creating a new plot.\n"
}], "Text"],

Cell[TextData[{
  StyleBox["How many bifurcations can you clearly see?  How many plots would \
you need to see 2 bifurcations? 3 bifurcations? 6 bifurcations?\n\n\t",
    FontSlant->"Italic"],
  "(answer here)"
}], "Text"],

Cell[TextData[{
  "When you are ready to print the whole thing out, please do the following \
to minimize paper usage\n\[Bullet]Go back through the document and clean \
things up, like deleting unnecessary returns, trial runs, and pesky messages \
about variables being named like other variables, etc...\n\[Bullet]Then click \
on ",
  StyleBox["Format",
    FontWeight->"Bold"],
  " on the ",
  StyleBox["Toolbar",
    FontWeight->"Bold"],
  " and choose ",
  StyleBox["Printing Style Environment -> Printout",
    FontWeight->"Bold"],
  ".\n\[Bullet]Under ",
  StyleBox["File",
    FontWeight->"Bold"],
  " click ",
  StyleBox["Printing Settings -> Page Setup",
    FontWeight->"Bold"],
  " and make sure you're set for Portrait.\n\[Bullet]Now under ",
  StyleBox["File",
    FontWeight->"Bold"],
  " click ",
  StyleBox["Print",
    FontWeight->"Bold"],
  ".  In the print dialog box choose the ",
  StyleBox["Layout",
    FontWeight->"Bold"],
  " tab and select ",
  StyleBox["2 pages per sheet",
    FontSlant->"Italic"],
  ".\n\[Bullet]Click ",
  StyleBox["Print",
    FontWeight->"Bold"],
  "."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
PrintingStyleEnvironment->"Printout",
WindowSize->{550, 608},
WindowMargins->{{14, Automatic}, {Automatic, -2}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 96, 5, 225, "Title"],
Cell[1826, 59, 329, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[2180, 70, 76, 1, 47, "Subsection"],
Cell[2259, 73, 1672, 50, 299, "Text"],
Cell[3934, 125, 449, 8, 130, "Input"],
Cell[4386, 135, 440, 19, 52, "Text"],
Cell[4829, 156, 138, 2, 50, "Input"],
Cell[4970, 160, 474, 14, 223, "Text"],
Cell[5447, 176, 749, 23, 109, "Text"],
Cell[6199, 201, 190, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6426, 209, 58, 1, 31, "Subsection"],
Cell[6487, 212, 1027, 26, 242, "Text"],
Cell[7517, 240, 252, 9, 52, "Text"],
Cell[7772, 251, 205, 4, 110, "Input"],
Cell[7980, 257, 129, 2, 50, "Input"],
Cell[8112, 261, 773, 21, 223, "Text"],
Cell[8888, 284, 125, 2, 90, "Input"],
Cell[9016, 288, 63, 0, 33, "Text"],
Cell[9082, 290, 313, 10, 52, "Text"],
Cell[9398, 302, 127, 2, 50, "Input"],
Cell[9528, 306, 452, 11, 166, "Text"],
Cell[9983, 319, 478, 14, 90, "Text"],
Cell[10464, 335, 143, 3, 50, "Input"],
Cell[10610, 340, 143, 3, 50, "Input"],
Cell[10756, 345, 639, 15, 223, "Text"],
Cell[11398, 362, 222, 5, 90, "Text"],
Cell[11623, 369, 1113, 36, 166, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

